@@ -6,4 +6,4 @@
 int cdda2wav(WINDOW *mainwin, struct conf *config);
 
 
-#endif // __CDDA2WAW
+#endif /* __CDDA2WAW */
