@@ -102,8 +102,8 @@ struct cddbwins {
 int size;
 char cdbpass[60];
 char msg[60];
-    
-// Function declarations 
+
+// Function declarations
 int add_to_dic_sub();
 void show_all();
 void delete_from_db(struct file_list_struct info);
@@ -131,7 +131,7 @@ int sqliteRegexpCompare(const unsigned char *zPattern, const unsigned char *zStr
     regfree(regex);
     if (rv)
 	return 0;
-    else 
+    else
 	return 1;
 }
 
@@ -212,7 +212,7 @@ int scan_content(char *dir, sqlite *sqlite_db, int cd_id, int dirlength)
 	    finfo=(struct stat *)malloc(sizeof(finfo)+100);
 	    ok=lstat(ch,finfo);
 	    type=S_ISLNK(finfo->st_mode);
-	    if ( (eps[cnt]->d_type=DT_DIR) && (type==0) ) 
+	    if ( (eps[cnt]->d_type=DT_DIR) && (type==0) )
 #ifdef HAVE_LIBMYSQLCLIENT
 		scan_content(ch, mysql, cd_id, dirlength);
 #endif
@@ -252,7 +252,7 @@ int scan_content(char *dir, sqlite *sqlite_db, int cd_id, int dirlength)
 void display_error(char *message)
 {
     if (LINES>0) {
-	dialogbox(message, _("Error"), 0);
+	    dialogbox(_("Error"), message, 0);
     } else {
 #ifdef GTK_GUI
 	gtk_error_dialog(message);
@@ -265,7 +265,7 @@ int connect_database()
     char message[200];
     FILE *dbfile;
     int do_create=2;
-#ifdef HAVE_LIBMYSQLCLIENT 
+#ifdef HAVE_LIBMYSQLCLIENT
     mysql_init(&mysql);
     if (!mysql_real_connect(&mysql, config.cdbhost, config.cdbuser, cdbpass, "cdw", 0, NULL, 0)){
 	sprintf(message, "%s", mysql_error(&mysql));
@@ -273,7 +273,7 @@ int connect_database()
 #ifdef HAVE_LIBSQLITE
     if ( (dbfile=fopen(config.sqlite_file, "r"))==NULL ){
 	if (LINES>0) {
-	    do_create=dialogbox(_("SQLite database file not exists!\nMay I create it?"), _("File not exists"), 3);
+		do_create=dialogbox(_("File not exists"), _("SQLite database file not exists!\nMay I create it?"), 3);
 	} else {
 #ifdef GTK_GUI
 	    if (gtk_message(_("SQLite database file not exists!\nMay I create it?"), _("File not exists")))	do_create=0;
@@ -303,7 +303,7 @@ int connect_database()
     if (!sqlite_db) {
 	sprintf(message, "%s", errmsg);
 #endif
-	if (strlen(message)<=0) 
+	if (strlen(message)<=0)
 	    sprintf(message, _("Unknown error! Check the settings!"));
 	display_error(message);
 	return 1;
@@ -336,17 +336,17 @@ MYSQL_RES* query_content(char *type, char *disk, char *dir)
 SQLITE_RES *query_content(char *type, char *disk, char *dir)
 #endif
 {
-    
+
     if (connect_database()==0){
 	sprintf(query, "SELECT cd.number, cd.name, content.file, content.size, content.date, type.name FROM content LEFT JOIN cd ON content.cd_id=cd.cd_id left join type on cd.type=type.type_id WHERE content.cd_id>0");
 	if (strcmp(dir, "*")!=0){
-	    sprintf(query, "%s AND UPPER(content.file) LIKE UPPER(\"%s/%%\")", query, dir);	    
+	    sprintf(query, "%s AND UPPER(content.file) LIKE UPPER(\"%s/%%\")", query, dir);
 	}
 	if (strcmp(disk,"*")!=0){
-	    sprintf(query, "%s AND cd.name='%s'", query, disk);	    
+	    sprintf(query, "%s AND cd.name='%s'", query, disk);
 	}
 	if (strcmp(type,"*")!=0){
-	    sprintf(query, "%s AND type.name='%s'", query, type);	    
+	    sprintf(query, "%s AND type.name='%s'", query, type);
 	}
 	sprintf(query, "%s ORDER BY cd.number, cd.name", query);
 #ifdef HAVE_LIBMYSQLCLIENT
@@ -386,16 +386,16 @@ SQLITE_RES *search_content(char *file, char *type, char *disk, char *dir)
 	sprintf(query, "SELECT cd.number, cd.name, content.file, content.size, content.date, type.name FROM content LEFT JOIN cd ON content.cd_id=cd.cd_id left join type on cd.type=type.type_id WHERE content.cd_id>0");
 #ifdef HAVE_LIBMYSQLCLIENT
 	if (strcmp(dir, "*")!=0){
-	    sprintf(query, "%s AND content.file REGEXP '%s'", query, dir);	    
+	    sprintf(query, "%s AND content.file REGEXP '%s'", query, dir);
 	}
 	if (strcmp(file, "*")!=0){
-	    sprintf(query, "%s AND content.file REGEXP '%s'", query, file);	    
+	    sprintf(query, "%s AND content.file REGEXP '%s'", query, file);
 	}
 	if (strcmp(disk,"*")!=0){
-	    sprintf(query, "%s AND cd.name=\"%s\"", query, disk);	    
+	    sprintf(query, "%s AND cd.name=\"%s\"", query, disk);
 	}
 	if (strcmp(type,"*")!=0){
-	    sprintf(query, "%s AND type.name=\"%s\"", query, type);	    
+	    sprintf(query, "%s AND type.name=\"%s\"", query, type);
 	}
 	sprintf(query, "%s ORDER BY cd.number, cd.name", query);
 	if (mysql_query(&mysql, query)) {
@@ -409,16 +409,16 @@ SQLITE_RES *search_content(char *file, char *type, char *disk, char *dir)
 #endif
 #ifdef HAVE_LIBSQLITE
 	if (strcmp(dir, "*")!=0){
-	    sprintf(query, "%s AND regexp('%s', content.file)", query, dir);	    
+	    sprintf(query, "%s AND regexp('%s', content.file)", query, dir);
 	}
 	if (strcmp(file, "*")!=0){
-	    sprintf(query, "%s AND regexp('%s', content.file)", query, file);	    
+	    sprintf(query, "%s AND regexp('%s', content.file)", query, file);
 	}
 	if (strcmp(disk,"*")!=0){
-	    sprintf(query, "%s AND cd.name=\"%s\"", query, disk);	    
+	    sprintf(query, "%s AND cd.name=\"%s\"", query, disk);
 	}
 	if (strcmp(type,"*")!=0){
-	    sprintf(query, "%s AND type.name=\"%s\"", query, type);	    
+	    sprintf(query, "%s AND type.name=\"%s\"", query, type);
 	}
 	sprintf(query, "%s ORDER BY cd.number, cd.name", query);
 	rc=sqlite_get_table(sqlite_db, query, &result->result, &result->nrow, &result->ncol, &errmsg);
@@ -508,7 +508,7 @@ int add_type(char *type)
 	if (mysql_query(&mysql, query)) {
 		display_error((char *)mysql_error(&mysql));
 		//fprintf(stderr, "%s: %s\n", _("Failed"), mysql_error(&mysql));
-	} 
+	}
 	mysql_close(&mysql);
 #endif
 #ifdef HAVE_LIBSQLITE
@@ -587,7 +587,7 @@ int switch_type(char *type)
 		display_error(errmsg);
 		//fprintf(stderr, "%s: %s\n", _("Failed"), errmsg);
 		return 1;
-	    } 
+	    }
 	    if (result->nrow>0) i=atoi(result->result[2]);
 	    else i=0;
 	    sqlite_free_table(result->result);
@@ -674,7 +674,7 @@ int delete_type(char *type)
 {
     int type_no;
     int cds[1000], i=0, z;
-    
+
     type_no=switch_type(type);
     if (connect_database()==0){
         sprintf(query, "DELETE FROM type WHERE type.type_id=%d", type_no);
@@ -744,7 +744,7 @@ int delete_type(char *type)
 	sqlite_close(sqlite_db);
 #endif
     }
-    for (z=0; z<i; z++){    
+    for (z=0; z<i; z++){
 	if (connect_database()==0){
     	    sprintf(query, "DELETE FROM content WHERE content.cd_id=%d", cds[z]);
 #ifdef HAVE_LIBMYSQLCLIENT
@@ -777,7 +777,7 @@ int load_disk(char *type, char *diskname, char* dir)
     int c=0, i, found, count, forcounter;
     char *line, itemname[100];
     char *linestr;
-    
+
     file_list[0].cd_num=0;
     file_list[0].files=(char *)malloc(1);
     file_list[0].files[0]='\0';
@@ -815,7 +815,7 @@ int load_disk(char *type, char *diskname, char* dir)
 	sqlite_close(sqlite_db);
 #endif
 	wrefresh(cddbwin.list);
-    }    
+    }
     if (dir_level==1) {
 	char num[6];
 	if ( (search!=1) && ((disk=query_disk(diskname, 0, type))!=NULL) ) {
@@ -885,7 +885,7 @@ int load_disk(char *type, char *diskname, char* dir)
 	sqlite_close(sqlite_db);
 #endif
 	wrefresh(cddbwin.list);
-    }    
+    }
     if (dir_level>=2) {
 	if (search==1){
 	    disk=search_content(file, type, diskname, dir);
@@ -982,7 +982,7 @@ void status_line(struct file_list_struct info)
     int maxpage, page;
     char page_str[10];
     char dir_str[255];
-    
+
     switch (info.type) {
 	case 0:
 	    strcpy(str, "Type");
@@ -998,7 +998,7 @@ void status_line(struct file_list_struct info)
 	    break;
     }
     werase(cddbwin.info);
-    if (search==1) 
+    if (search==1)
 	mvwprintw(cddbwin.select, 0, getmaxx(cddbwin.select)-strlen(_(" Search [ ] "))-1, _(" Search [X] "));
     else
 	mvwprintw(cddbwin.select, 0, getmaxx(cddbwin.select)-strlen(_(" Search [ ] "))-1, _(" Search [ ] "));
@@ -1087,11 +1087,11 @@ void print_highlight(int pos, struct file_list_struct file_p, int isreverse)
 void cddb_menu()
 {
     int c;
-    
+
     print_highlight(pos, file_list[pos], 0);
     wrefresh(cddbwin.list);
-    status_line(file_list[pos]);	    
-    
+    status_line(file_list[pos]);
+
     while (c!=KEY_LEFT) {
 	c=wgetch(cddbwin.main);
 	switch(c){
@@ -1119,7 +1119,7 @@ void cddb_menu()
 			screenpos=pos%getmaxy(cddbwin.list);
 			print_highlight(screenpos, file_list[pos], 0);
 			wrefresh(cddbwin.list);
-		    }		    
+		    }
 		}
 		break;
 	    case KEY_END:
@@ -1140,7 +1140,7 @@ void cddb_menu()
 		    screenpos=pos%getmaxy(cddbwin.list);
 		    print_highlight(screenpos, file_list[pos], 0);
 		    wrefresh(cddbwin.list);
-		}		    
+		}
 		break;
 	    case KEY_HOME:
 		if (pos>0) {
@@ -1157,7 +1157,7 @@ void cddb_menu()
 		    screenpos=0;
 		    print_highlight(screenpos, file_list[pos], 0);
 		    wrefresh(cddbwin.list);
-		}		    
+		}
 		break;
 	    case KEY_UP:
 		if (pos>0) {
@@ -1183,19 +1183,19 @@ void cddb_menu()
 			screenpos=getmaxy(cddbwin.list)-1;
 			print_highlight(screenpos, file_list[pos], 0);
 			wrefresh(cddbwin.list);
-		    }		    
+		    }
 		}
 		break;
 	    case 10:
 		if (file_list[pos].type==0) {
 		    dir_level=dir_level+1;
-		    wattrset(cddbwin.list, COLOR_PAIR(1));		    
+		    wattrset(cddbwin.list, COLOR_PAIR(1));
 		    werase(cddbwin.list);
 		    sprintf(var_type, "%s", file_list[pos].files);
 		    load_disk((char *)var_type, "*", "*");
 		    if (file_list[0].cd_num==0){
 			dir_level=0;
-			wattrset(cddbwin.list, COLOR_PAIR(1));		    
+			wattrset(cddbwin.list, COLOR_PAIR(1));
 			werase(cddbwin.list);
 			sprintf(var_type, "%s", file_list[pos].files);
 			load_disk((char *)var_type, "*", "*");
@@ -1204,7 +1204,7 @@ void cddb_menu()
 		}
 		else if (file_list[pos].type==1) {
 		    dir_level=dir_level+1;
-		    wattrset(cddbwin.list, COLOR_PAIR(1));		    
+		    wattrset(cddbwin.list, COLOR_PAIR(1));
 		    werase(cddbwin.list);
 		    sprintf(var_disk, "%s", file_list[pos].files);
 		    sprintf(var_dir, "*");
@@ -1213,7 +1213,7 @@ void cddb_menu()
 		}
 		else if (file_list[pos].type==2) {
 		    dir_level=dir_level+1;
-		    wattrset(cddbwin.list, COLOR_PAIR(1));		    
+		    wattrset(cddbwin.list, COLOR_PAIR(1));
 		    werase(cddbwin.list);
 		    if (dir_level>3)
 			sprintf(var_dir, "%s/%s", var_dir, file_list[pos].files);
@@ -1227,7 +1227,7 @@ void cddb_menu()
 	    case '/':
 		if (dir_level==1) {
 		    dir_level--;
-		    wattrset(cddbwin.list, COLOR_PAIR(1));		    
+		    wattrset(cddbwin.list, COLOR_PAIR(1));
 		    werase(cddbwin.list);
 		    sprintf(var_disk, "*");
 		    sprintf(var_type, "*");
@@ -1237,7 +1237,7 @@ void cddb_menu()
 		}
 		else if (dir_level==2) {
 		    dir_level--;
-		    wattrset(cddbwin.list, COLOR_PAIR(1));		    
+		    wattrset(cddbwin.list, COLOR_PAIR(1));
 		    werase(cddbwin.list);
 		    sprintf(var_disk, "*");
 		    sprintf(var_dir, "*");
@@ -1246,7 +1246,7 @@ void cddb_menu()
 		}
 		else if (dir_level==3) {
 		    dir_level--;
-		    wattrset(cddbwin.list, COLOR_PAIR(1));		    
+		    wattrset(cddbwin.list, COLOR_PAIR(1));
 		    werase(cddbwin.list);
 		    sprintf(var_dir, "*");
 		    werase(cddbwin.list);
@@ -1256,7 +1256,7 @@ void cddb_menu()
 		else if (dir_level>3) {
 		    char *dir;
 		    char *line;
-		    
+
 		    dir_level--;
 		    line=(char *) malloc(strlen(var_dir)+5);
 		    sprintf(line, "%s", var_dir);
@@ -1266,7 +1266,7 @@ void cddb_menu()
 			dir=strtok(NULL, "/");
 			sprintf(var_dir, "%s/%s", var_dir, dir);
 		    }
-		    wattrset(cddbwin.list, COLOR_PAIR(1));		    
+		    wattrset(cddbwin.list, COLOR_PAIR(1));
 		    werase(cddbwin.list);
 		    load_disk((char *)var_type, (char *)var_disk, (char *)var_dir);
 		    pos=0;
@@ -1282,11 +1282,11 @@ void cddb_menu()
 		    if (dir_level==0) {
 			char message[600];
 			sprintf(message, "%s\n %s?", _("Are you sure do you want to delete category:"), file_list[pos].files);
-			if (dialogbox(message, _("Confirm"), 3)==0) {
+			if (dialogbox(_("Confirm"), message, 3)==0) {
 			   delete_from_db(file_list[pos]);
 			   if (file_list[0].cd_num==0){
 			      dir_level=0;
-			      wattrset(cddbwin.list, COLOR_PAIR(1));		    
+			      wattrset(cddbwin.list, COLOR_PAIR(1));
 			      werase(cddbwin.list);
 			      sprintf(var_type, "%s", file_list[pos].files);
 			      load_disk((char *)var_type, "*", "*");
@@ -1296,18 +1296,18 @@ void cddb_menu()
 		    if (dir_level==1) {
 			char message[600];
 			sprintf(message, "%s\n %s?", _("Are you sure do you want to delete disk:"), file_list[pos].files);
-			if (dialogbox(message, _("Confirm"), 3)==0) {
+			if (dialogbox(_("Confirm"), message, 3)==0) {
 			   delete_from_db(file_list[pos]);
 			   if (file_list[0].cd_num==0){
 			       dir_level=0;
-			       wattrset(cddbwin.list, COLOR_PAIR(1));		    
+			       wattrset(cddbwin.list, COLOR_PAIR(1));
 			       werase(cddbwin.list);
 			       sprintf(var_type, "%s", file_list[pos].files);
 			       load_disk((char *)var_type, "*", "*");
 			   }
 			}
 		    }
-		    wrefresh(derwin(cddbwin.main,LINES-1,COLS-1,0,0));    
+		    wrefresh(derwin(cddbwin.main,LINES-1,COLS-1,0,0));
 		}
 		break;
 	    case 'S':
@@ -1321,7 +1321,7 @@ void cddb_menu()
 	        screenpos=pos%getmaxy(cddbwin.list);
 	    print_highlight(screenpos, file_list[pos], 0);
 	    wrefresh(cddbwin.list);
-	    status_line(file_list[pos]);	    
+	    status_line(file_list[pos]);
     }
     if (pos<getmaxy(cddbwin.list))
 	screenpos=pos;
@@ -1351,9 +1351,9 @@ void main_screen()
     strcpy(cddbmenu_const.scr, _(" Search         "));
     strcpy(cddbmenu_const.del, _(" Delete         "));
     strcpy(cddbmenu_const.qut, _(" Quit Catalog   "));
-    
+
     items = (ITEM **)calloc(11, sizeof(ITEM *));
-    
+
     items[0]=new_item(cddbmenu_const.all, "");
     items[1]=new_item(cddbmenu_const.add, "");
     items[2]=new_item(cddbmenu_const.scr, "");
@@ -1361,7 +1361,7 @@ void main_screen()
     items[4]=new_item(cddbmenu_const.qut, "");
     items[5]=new_item((char *)0, "");
     // *****************
-    
+
     cddbmenu = new_menu((ITEM **)items);
     set_menu_win(cddbmenu, cddbwin.main);
     set_menu_sub(cddbmenu, derwin(cddbwin.main, LINES-8, 26, 5, 3));
@@ -1395,7 +1395,7 @@ void main_screen()
 void insert_disk(char *disk, char *cd_num, char *type)
 {
     int id;
-    
+
     if (switch_type((char *)type)==0){
 	add_type((char *)type);
     }
@@ -1415,8 +1415,8 @@ int add_to_dic_sub()
 	sprintf(var_disk, "*");
 	sprintf(var_dir, "*");
 	i=load_disk("*", "*", "*");
-	pos=0;    
-	status_line(file_list[pos]);	    
+	pos=0;
+	status_line(file_list[pos]);
     }
     if ( strcmp(config.eject, "1")==0 ){
         eject_tray(config.cdrom);
@@ -1448,7 +1448,7 @@ int search_in_dic()
 	   sprintf(var_disk, "*");
 	   sprintf(var_dir, "*");
 	   i=load_disk("*", "*", "*");
-	   pos=0;    
+	   pos=0;
 	   status_line(file_list[pos]);
 	}
 	else {
@@ -1461,8 +1461,8 @@ int search_in_dic()
 		sprintf(var_disk, "*");
 		sprintf(var_dir, "*");
 		i=load_disk("*", "*", "*");
-		pos=0;    
-		status_line(file_list[pos]);	    
+		pos=0;
+		status_line(file_list[pos]);
 	}
     }
 }
@@ -1479,13 +1479,13 @@ void show_all()
     search=0;
     i=load_disk("*", "*", "*");
     pos=0;
-    status_line(file_list[pos]);	    
+    status_line(file_list[pos]);
 }
 
 void delete_from_db(struct file_list_struct info)
 {
     int cd_id;
-    
+
     if (dir_level==1) {
 	cd_id=delete_disk(info.files, info.cd_num, info.type_name);
 	delete_content(cd_id);
@@ -1494,7 +1494,7 @@ void delete_from_db(struct file_list_struct info)
 	wrefresh(cddbwin.info);
 	i=load_disk(var_type, var_disk, "*");
 	pos=0;
-	status_line(file_list[pos]);	    
+	status_line(file_list[pos]);
     }
     if (dir_level==0) {
 	werase(cddbwin.info);
@@ -1503,7 +1503,7 @@ void delete_from_db(struct file_list_struct info)
 	delete_type(info.files);
 	i=load_disk("*", "*", "*");
 	pos=0;
-	status_line(file_list[pos]);	    
+	status_line(file_list[pos]);
     }
 }
 
@@ -1512,7 +1512,7 @@ int cddb_window()
     char *in;
     int c, i=-1, page=1, quit=0, passwd_entered;
 
-    config=read_conf();
+    read_conf();
     strcpy(cdbpass, "\0");
     sprintf(msg, "%s %s", config.cdbuser, _("password"));
 #ifdef HAVE_LIBMYSQLCLIENT
@@ -1535,15 +1535,15 @@ int cddb_window()
 	result=(SQLITE_RES *)malloc(sizeof(SQLITE_RES));
 #endif
 	i=load_disk("*", "*", "*");
-	pos=0;    
-	status_line(file_list[pos]);	    
+	pos=0;
+	status_line(file_list[pos]);
 	while ( (c!='q') && (quit==0) ){
 	    c=wgetch(cddbwin.main);
 	    switch(c){
 		// -------- MENU --------
 		case KEY_F(1):
 		    show_help_cddb();
-		    wrefresh(derwin(cddbwin.main,LINES-1,COLS-1,0,0));    
+		    wrefresh(derwin(cddbwin.main,LINES-1,COLS-1,0,0));
 		    break;
 		case 'A':
 		case 'a':
@@ -1583,7 +1583,7 @@ int cddb_window()
 		    // Search
 		    if ( item_index(current_item(cddbmenu)) == 2 ){
 			search_in_dic();
-			wrefresh(derwin(cddbwin.main,LINES-1,COLS-1,0,0));    
+			wrefresh(derwin(cddbwin.main,LINES-1,COLS-1,0,0));
 		    }
 		    // Delete
 		    if ( item_index(current_item(cddbmenu)) == 3 ){
@@ -1591,11 +1591,11 @@ int cddb_window()
 			    if (dir_level==0) {
 				char message[600];
 				sprintf(message, "%s\n %s?", _("Are you sure do you want to delete category:"), file_list[pos].files);
-				if (dialogbox(message, _("Confirm"), 3)==0) {
+				if (dialogbox(_("Confirm"), message, 3)==0) {
 				   delete_from_db(file_list[pos]);
 				   if (file_list[0].cd_num==0){
 				      dir_level=0;
-				      wattrset(cddbwin.list, COLOR_PAIR(1));		    
+				      wattrset(cddbwin.list, COLOR_PAIR(1));
 				      werase(cddbwin.list);
 				      sprintf(var_type, "%s", file_list[pos].files);
 				      load_disk((char *)var_type, "*", "*");
@@ -1605,11 +1605,11 @@ int cddb_window()
 			    if (dir_level==1) {
 			       char message[600];
 			       sprintf(message, "%s\n %s?", _("Are you sure do you want to delete disk:"), file_list[pos].files);
-			       if (dialogbox(message, _("Confirm"), 3)==0) {
+			       if (dialogbox(_("Confirm"), message, 3)==0) {
 				   delete_from_db(file_list[pos]);
 				   if (file_list[0].cd_num==0){
 				       dir_level=0;
-				       wattrset(cddbwin.list, COLOR_PAIR(1));		    
+				       wattrset(cddbwin.list, COLOR_PAIR(1));
 				       werase(cddbwin.list);
 				       sprintf(var_type, "%s", file_list[pos].files);
 				       load_disk((char *)var_type, "*", "*");
@@ -1617,7 +1617,7 @@ int cddb_window()
 			       }
 			    }
 			}
-			wrefresh(derwin(cddbwin.main,LINES-1,COLS-1,0,0));    
+			wrefresh(derwin(cddbwin.main,LINES-1,COLS-1,0,0));
 		    }
 		    // Quit
 		    if ( item_index(current_item(cddbmenu)) == 4){
