@@ -40,7 +40,7 @@
 #include "main.h"
 #include "utils.h"
 #include "cdw_tmp_files.h"
-
+#include "cdw_widgets.h"
 
 
 #define MENU_ITEMS 8 /* amount of items in main cdw menu on the left */
@@ -50,10 +50,10 @@ struct curses_menu {
 	char add[22];
 	char del[22];
 	char cre[22];
-	// char cpi[22]; not in this release
+	/* char cpi[22]; not in this release */
 	char wri[22];
-	// char wau[22]; not in this release
-	// char cdc[22]; not in this release
+	/* char wau[22]; not in this release */
+	/* char cdc[22]; not in this release */
 	char blk[22];
 	char opt[22];
 	char qut[22];
@@ -80,16 +80,16 @@ char *TITLE = NULL;
 MENU *menu = NULL;
 MENU *cdmenu = NULL;
 
-// WINDOW *menuwin, *mainwin, *addwin, *menuwin_sub, *addwinlist;
+/* WINDOW *menuwin, *mainwin, *addwin, *menuwin_sub, *addwinlist; */
 
-WINDOW *mainwin; /* main application window */
-WINDOW *addwin;
-WINDOW *menuwin_sub;
-WINDOW *addwinlist;
-WINDOW *menuwin;
+WINDOW *mainwin = NULL; /* main application window */
+WINDOW *addwin = NULL;
+WINDOW *menuwin_sub = NULL;
+WINDOW *addwinlist = NULL;
+WINDOW *menuwin = NULL;
 
 
-void clean_title(void)
+void title_clean(void)
 {
 	if (TITLE != NULL) {
 		free(TITLE);
@@ -118,10 +118,10 @@ void fill_info(void)
 
 
 
-/* 
+/*
  * Simple file selector window
  *
- * File/directory selection window with one list of files. Allows browsing 
+ * File/directory selection window with one list of files. Allows browsing
  * tree of directories using keyboard.
  *
  * Uses global variables addwinlist and filei.
@@ -171,7 +171,7 @@ void load_dir(char *dir, int width, int height)
 	free(eps);
 	eps = NULL;
 
-	nice_box(addwin, _("Add files"), dir, width);
+	nice_box(addwin, _("Add files"), dir);
 
 	wrefresh(addwin);
 }
@@ -180,16 +180,16 @@ void load_dir(char *dir, int width, int height)
 
 
 /*
- * Display one item (and its attributes) from directory listing list 
+ * Display one item (and its attributes) from directory listing list
  *
- * Display in given row one item from directory listing list, set its 
+ * Display in given row one item from directory listing list, set its
  * font/background properly, display additional attributes in the same row.
  *
  * Set color of direcrory listing item based on its type (dir or regular file).
  *
  * \param int pos - position on list (position in window)
  * \param fileitem file_p - file item with file properties (name, type, size)
- * \param int isreverse - if = 0 then black background and light font, 
+ * \param int isreverse - if = 0 then black background and light font,
  *                         otherwise reverse attributes applied
  */
 void highlight(int pos, fileitem file_p, int isreverse)
@@ -214,7 +214,7 @@ void highlight(int pos, fileitem file_p, int isreverse)
 
 
 
-/*
+/**
  * Show window that allows user to select files and directories
  *
  * Show window that allows user to select files and directories
@@ -244,7 +244,7 @@ void put_addwin(int width, int height, int y, int x)
 	wattrset(addwin, A_NORMAL | COLOR_PAIR(2));
 	addwinlist = derwin(addwin, width - 2, height - 2, 1, 1);
 
-	nice_box(addwin, _("Add files"), "", 0);
+	nice_box(addwin, _("Add files"), ""); /* second string would be erased by 'current dir path' string */
 
 	sprintf(path, "%s", getenv("HOME"));
 	load_dir(path, width, height);
@@ -318,7 +318,7 @@ void put_addwin(int width, int height, int y, int x)
 					highlight(screenpos, filei[menupos], 1);
 					menupos = 0; // we are on top of dir listing, so there is only one place to move cursor and file index
 					screenpos = 0;
-				} else { 
+				} else {
 					menupos -= getmaxy(addwinlist); // move file index exactly one screensize up
 					// screenpos = screenpos; // cursor does not change its position
 					werase(addwinlist);
@@ -329,7 +329,13 @@ void put_addwin(int width, int height, int y, int x)
 			}
 			break;
 		case KEY_NPAGE: /* Next Page, Page Down */
-			if ((maxfiles - menupos) > getmaxy(addwinlist) - 1) { // (remainder of) dir listing is long enough to move it by whole page 
+			if ((maxfiles - menupos) > getmaxy(addwinlist) - 1) {
+				/* (remainder of) dir listing is long enough
+				   to move it by whole page */
+				/* cursoir does not change it's relative
+				   position, because if we scroll list by
+				   whole page, the cursor will still be on
+				   valid position */
 				highlight(screenpos, filei[menupos], 1);
 				menupos += getmaxy(addwinlist);
 				// screenpos = screenpos;
@@ -337,15 +343,16 @@ void put_addwin(int width, int height, int y, int x)
 				scroll_addlist(addwinlist, menupos, filei, maxfiles);
 				highlight(screenpos, filei[menupos], 0);
 				wrefresh(addwinlist);
-			} else { // move cursor to last item on the list, display reminder of the list
-				/* it almost works
-				screenpos = maxfiles % getmaxy(addwinlist);
-				menupos = maxfiles;
+			} else {
+				/* move cursor to last item on the list,
+				   display remainder of the list; cursor
+				   will have to change it's position */
+				screenpos = maxfiles % getmaxy(addwinlist); /* relative position of cursor */
+				menupos = maxfiles;  /* non-relative number of highlighted item */
 				werase(addwinlist);
 				scroll_addlist(addwinlist, menupos, filei, maxfiles);
 				highlight(screenpos, filei[menupos], 0);
 				wrefresh(addwinlist);
-				*/
 			}
 			break;
 		/* Chdir */
@@ -387,13 +394,13 @@ void put_addwin(int width, int height, int y, int x)
 		case ' ':
 			/* copy full path of selected file to linkfile */
 			strcpy(linkfile, path); /* path = full current dir path */
-			strcat(linkfile, "/");  
+			strcat(linkfile, "/");
 			strcat(linkfile, filei[menupos].filename); /* name of selected file/dir */
 
 			/* add this full path to files list */
 			rv = filelist_add(linkfile);
-			
-			nice_box(addwin, _("Add files"), path, width);
+
+			nice_box(addwin, _("Add files"), path);
 
 			select_window(TRUE);
 			break;
@@ -412,7 +419,7 @@ void put_addwin(int width, int height, int y, int x)
 
 
 
-void put_mainform()
+void mainform_init()
 {
 	WINDOW *select_sub;
 
@@ -465,7 +472,7 @@ void put_mainform()
 	select_sub = derwin(mainwin, LINES - 7, COLS - 29, 3, 27);
 
 	keypad(select_sub, TRUE);
-	nice_box(select_sub, _("Selected files"), "", 0);
+	nice_box(select_sub, _("Selected files"), "");
 	wattrset(select_sub, A_NORMAL | COLOR_PAIR(1));
 
 	mvwaddch(select_sub, LINES - 13, 0, ACS_LTEE);
@@ -477,7 +484,7 @@ void put_mainform()
 
 	/* Left hand cdw menu */
 	menuwin_sub = derwin(mainwin, LINES - 7, 26, 3, 1);
-	nice_box(menuwin_sub, _("Menu"), "", 0);
+	nice_box(menuwin_sub, _("Menu"), "");
 
 	mvwaddch(menuwin_sub, LINES - 13, 0, ACS_LTEE);
 	mvwhline(menuwin_sub, LINES - 13, 1, ACS_HLINE, 24);
@@ -500,10 +507,10 @@ void put_mainform()
  *
  * \returns 0
  */
-int destroy_mainform(void)
+int mainform_clean(void)
 {
-	clean_cdmenu();
-	clean_menu();
+	cdmenu_clean();
+	menu_clean();
 	delwin(mainwin);
 	mainwin = NULL;
 
@@ -513,11 +520,11 @@ int destroy_mainform(void)
 
 
 
-/* 
+/*
  * Delete file(s) from list of selected files
  *
- * Delete file(s) from list of selected files. This function will move 
- * cursor to list of currently selected files and let user remove (using 
+ * Delete file(s) from list of selected files. This function will move
+ * cursor to list of currently selected files and let user remove (using
  * Delete button) remove item(s) from this list.
  */
 void delete_files(void)
@@ -541,7 +548,7 @@ void delete_files(void)
 			break;
 		case KEY_DC:
 			/* FIXME - merge those two lines */
-			strcpy(filetodelete, item_name(current_item(cdmenu))); 
+			strcpy(filetodelete, item_name(current_item(cdmenu)));
 			filelist_remove(filetodelete);
 
 			select_window(TRUE);
@@ -556,6 +563,29 @@ void delete_files(void)
 }
 
 
+
+int move_radio_selection(WINDOW * window, int radiobutton_number)
+{
+	mvwaddch(window, 4, 3, ' ');
+	mvwaddch(window, 5, 3, ' ');
+	mvwaddch(window, 6, 3, ' ');
+	mvwaddch(window, 7, 3, ' ');
+	if (radiobutton_number == 0) {
+		mvwaddch(window, 4, 3, '*');
+	} else if (radiobutton_number == 1) {
+		mvwaddch(window, 5, 3, '*');
+	} else if (radiobutton_number == 2) {
+		mvwaddch(window, 6, 3, '*');
+	} else if (radiobutton_number == 3){
+		mvwaddch(window, 7, 3, '*');
+	}
+
+	return radiobutton_number;
+}
+
+
+
+
 /*
  * Show window allowing user to select disk size
  */
@@ -563,70 +593,80 @@ void size_selector(void)
 {
 	WINDOW *volwin, *edit;
 	int ch = 0;
+	int rv = 0; // return value
 	char cdsize[20];
 
 	volwin = newwin(10, 30, (LINES - 10) / 2, (COLS - 30) / 2);
 	wbkgd(volwin, COLOR_PAIR(2));
 	werase(volwin);
 
-	nice_box(volwin, _("CD size"), "", 0);
-	
+	nice_box(volwin, _("CD size"), "");
+
 	mvwprintw(volwin, 2, 3, _("Select CD size"));
-	mvwprintw(volwin, 4, 5, "1 - 74 Min (650 MB)");
-	mvwprintw(volwin, 5, 5, "2 - 80 Min (700 MB)");
-	mvwprintw(volwin, 6, 5, "3 - DVD - (4700 MB)");
-	mvwprintw(volwin, 7, 5, "4 -");
-	edit = derwin(volwin, 1, 4, 7, 9);
+	mvwprintw(volwin, 4, 5, _("1 - 74 Min (650 MB)"));
+	mvwprintw(volwin, 5, 5, _("2 - 80 Min (700 MB)"));
+	mvwprintw(volwin, 6, 5, _("3 - DVD - (4700 MB)"));
+	mvwprintw(volwin, 7, 5, _("4 -"));
+
+	// small, one-line text input area
+	edit = derwin(volwin, 1, 8, 7, 9);
 	wbkgd(edit, COLOR_PAIR(6));
 	werase(edit);
-	sprintf(cdsize, "%d", config.cdsize);
+
+	// initial value displayed in text input area
+	sprintf(cdsize, "%d", config.user_cdsize);
 	mvwprintw(edit, 0, 0, cdsize);
+
 	switch (config.cdsize) {
-	case 657:
-		mvwaddch(volwin, 4, 3, '*');
-		break;
-	case 702:
-		mvwaddch(volwin, 5, 3, '*');
-		break;
-	case 4700:
-		mvwaddch(volwin, 6, 3, '*');
-		break;
-	default:
-		mvwaddch(volwin, 7, 3, '*');
-		break;
+		case 657:
+			move_radio_selection(volwin, 0);
+			break;
+		case 702:
+			move_radio_selection(volwin, 1);
+			break;
+		case 4700:
+			move_radio_selection(volwin, 2);
+			break;
+		default:
+			move_radio_selection(volwin, 3);
+			break;
 	}
+
 	wrefresh(edit);
 	wmove(volwin, 9, 29);
-	while ((ch != 27) && (ch != 10)) {
+	while ((ch != CDW_ESCAPE) && (ch != CDW_ENTER)) {
 		ch = wgetch(volwin);
 		switch (ch) {
-		case '1':
-			config.cdsize = 657;
-			break;
-		case '2':
-			config.cdsize = 702;
-			break;
-		case '3':
-			config.cdsize = 4700;
-			break;
-		case '4':
-			sprintf(cdsize, "%d", config.cdsize);
-			inbox(edit, cdsize);
-			config.cdsize = atoi(cdsize);
-			break;
+			case '1':
+				move_radio_selection(volwin, 0);
+				config.cdsize = 657;
+				break;
+			case '2':
+				move_radio_selection(volwin, 1);
+				config.cdsize = 702;
+				break;
+			case '3':
+				move_radio_selection(volwin, 2);
+				config.cdsize = 4700;
+				break;
+			case '4':
+				move_radio_selection(volwin, 3);
+				wrefresh(volwin);
+				sprintf(cdsize, "%d", config.user_cdsize);
+				rv = inbox(edit, cdsize, false);
+
+				if (rv == 0) { // escape pressed, use previous selection
+					;
+				} else { // enter pressed, use entered value
+					config.cdsize = atoi(cdsize);
+					config.user_cdsize = atoi(cdsize);
+				}
+				break;
 		}
-		mvwaddch(volwin, 4, 3, ' ');
-		mvwaddch(volwin, 5, 3, ' ');
-		mvwaddch(volwin, 6, 3, ' ');
-		if (config.cdsize == 657)
-			mvwaddch(volwin, 4, 3, '*');
-		else if (config.cdsize == 702)
-			mvwaddch(volwin, 5, 3, '*');
-		else
-			mvwaddch(volwin, 6, 3, '*');
+
 		wrefresh(volwin);
 	}
-	write_conf(config);
+	write_conf();
 
 	delwin(volwin);
 	return;
@@ -635,14 +675,14 @@ void size_selector(void)
 
 
 
-/* 
+/*
  * Display CD usage summary on bottom of cdw window
  *
- * Display amount of space used by selected files, amount of 
- * space that would stay free disk, and percent of CD disk usage.
+ * Display amount of space used by selected files, amount of
+ * space that would stay free on disk, and percent of CD disk usage.
  * CD\DVD size is taken from config panel/file.
  *
- * \param double size - size of selected files
+ * \param double files_size - size of selected files
  */
 void show_disk_usage(double files_size)
 {
@@ -676,13 +716,13 @@ void show_disk_usage(double files_size)
 /*
  * Refresh content of main app window
  *
- * Refresh content of main app window - the one containing menu 
- * on the left and selected files/dirs list on the right + some 
- * statistics at the bottom. This may need reading (possibly) 
+ * Refresh content of main app window - the one containing menu
+ * on the left and selected files/dirs list on the right + some
+ * statistics at the bottom. This may need reading (possibly)
  * changed content of files-to-cd listing.
  *
- * \param bool real - do you want to refresh content of main 
- *        window by re-reading it from listing on hard-disk 
+ * \param bool real - do you want to refresh content of main
+ *        window by re-reading it from listing on hard-disk
  *        (may be time-consuming)?
  *
  * \returns 0
@@ -697,13 +737,13 @@ int select_window(bool real)
 	WINDOW *select_sub;
 
 	/* Do time-consuming refresh of file list?
-	 * It is time consuming, because this is not ordinary curses 
-	 * wrefresh(), this code has to allocate some memory and move data from 
+	 * It is time consuming, because this is not ordinary curses
+	 * wrefresh(), this code has to allocate some memory and move data from
 	 * one place to another and print this data to screen. */
-	if (real == TRUE) { 
+	if (real == TRUE) {
 
 		/* clean up previous selected files list and all associated data structures */
-		clean_cdmenu();
+		cdmenu_clean();
 
 		/* fill table with selected files paths, return number of paths */
 		num = filelist_items(&filetable);
@@ -720,10 +760,10 @@ int select_window(bool real)
 
 		if (num > 0) {
 			int i;
-			/* this file list is in reality a ncurses menu, so 
+			/* this file list is in reality a ncurses menu, so
 			 * we will use menu **ITEM data structure (cditems) here */
 			for (i = 0; i < num; ++i) {
-				/* FIXME find a way to save path with file type 
+				/* FIXME find a way to save path with file type
 				 * like it was done in original implementation of cdw */
 				/*
 				if (cdfiles[i]->d_type == DT_DIR) {
@@ -737,14 +777,14 @@ int select_window(bool real)
 				cditems[pos++] = new_item( *(filetable + i), "    " );
 			}
 		}
-			
-		/* Let's continue constructing ncurses menu cdmenu using 
+
+		/* Let's continue constructing ncurses menu cdmenu using
 		 * ncurses data structure **ITEM cditems. Note that this menu
 		 * will be constructed even if there are no files */
 
 		/* last element must be NULL - ncurses requirement */
-		cditems[num] = (ITEM *) NULL; 
-		
+		cditems[num] = (ITEM *) NULL;
+
 		cdmenu = new_menu((ITEM **) cditems);
 		set_menu_win(cdmenu, mainwin);
 		set_menu_sub(cdmenu, derwin(mainwin, LINES - 12, COLS - 31, 4, 28));
@@ -755,7 +795,7 @@ int select_window(bool real)
 
 	}
 
-	/* rest of function redraws frames and it's content 
+	/* rest of function redraws frames and it's content
 	 * at the bottom of window */
 
 	select_sub = derwin(mainwin, LINES - 10, COLS - 29, 3, 27);
@@ -786,110 +826,6 @@ int select_window(bool real)
 
 
 
-/**
- * Display widget allowing to enter simple string value
- *
- * Display widget with title and label, allowing user to enter simple 
- * value, like label, path or number. Parameter "mode" puts restrictions
- * on entered value.
- *
- * \param char *title - window title
- * \param char *label - label put into window
- * \param char *prop - string containing entered value
- * \param int mode - widget mode, puts some restrictions on entered value
- *
- * \returns - TBD
- */
-int input_box(char *title, char *label, char *prop, int mode)
-{
-	WINDOW *volwin;
-	// WINDOW *edit;
-	FIELD *field[1];
-	FORM *form1;
-	int ret;
-	int ch;
-
-	/* dialog window */
-	volwin = newwin(10, 50, (LINES - 10) / 2, (COLS - 50) / 2);
-	keypad(volwin, TRUE);
-	wbkgd(volwin, COLOR_PAIR(2));
-	werase(volwin);
-	nice_box(volwin, _(title), "", 0);
-	mvwprintw(volwin, 3, 3, _(label));
-
-	/* input field 
-	 * new_field params: height, width, starty, startx, number of 
-	 * offscreen rows and number of additional working buffers */
-	field[0] = new_field(1, 44, 0, 0, 0, 0);
-	set_field_buffer(field[0], 0, prop);
-	set_field_back(field[0], COLOR_PAIR(6));
-	set_field_fore(field[0], COLOR_PAIR(6));
-	field_opts_off(field[0], O_STATIC); /* stretch to fit entered data */
-	set_max_field(field[0], 200); /* limit stretching of the field; FIXME - arbitrary magic number */
-	field[1] = NULL;
-
-	/* form containing field. placed in window */
-	form1 = new_form(field);
-	set_form_win(form1, volwin);
-	set_form_sub(form1, derwin(volwin, 1, 44, 5, 2));
-	post_form(form1);
-	
-	set_current_field(form1, field[0]);
-	form_driver(form1, REQ_END_LINE);
-	wrefresh(volwin);
-
-	ch = 0;
-	while ((ch != 27) && (ch != 10)) {
-		ch = wgetch(volwin);
-		switch (ch) {
-		case KEY_LEFT:
-			form_driver(form1, REQ_PREV_CHAR);
-			break;
-		case KEY_RIGHT:
-			form_driver(form1, REQ_NEXT_CHAR);
-			break;
-		case KEY_BACKSPACE:
-			form_driver(form1, REQ_DEL_PREV);
-			break;
-		case KEY_DC:
-			form_driver(form1, REQ_DEL_CHAR);
-			break;
-		case KEY_F(10):
-		case 10:
-			// return main loop
-			form_driver(form1, REQ_VALIDATION);
-			sprintf(prop, rtrim(field_buffer(field[0], 0)));
-			write_conf(config);
-			//return ch;
-			break;
-		default:
-			/* push char ch to form */
-			form_driver(form1, ch);
-			break;
-			wrefresh(volwin);
-		}
-	}
-
-/*    edit=derwin(volwin, 1, 24, 5, 3);
-    wbkgd(edit, COLOR_PAIR(6));
-    werase(edit);
-    wrefresh(edit);
-    ret=inbox(edit, prop);*/
-
-	/* clean up */
-	unpost_form(form1);
-	free_form(form1);
-	free_field(field[0]);
-	delwin(volwin);
-	wrefresh(volwin);
-
-	if (ch == 27)
-		ret = 0;
-	else
-		ret = 1;
-	write_conf(config);
-	return ret;
-}
 
 
 
@@ -906,20 +842,20 @@ void scroll_addlist(WINDOW *addwinlist, int menupos, fileitem *filei, int maxfil
 {
 	int startpos = 0; // index of first file that will be displayed in scrolled window
 	int i; /* rows index of addwinlist window */
-	
+
 	/* start displaying items starting from item with index equal (menupos - "cursor position");
 	 * cursor position is (menupos % getmaxy(addwinlist)) - this is cursor pos. in window */
 	startpos = menupos - (menupos % getmaxy(addwinlist));
 
-	
+
 	/* increment window row number and dir listing index at the same time */
-	for (i = 0, startpos; 
-	     startpos <= maxfiles, i < getmaxy(addwinlist); 
+	for (i = 0, startpos;
+	     startpos <= maxfiles && i < getmaxy(addwinlist);
 	     i++, startpos++) {
 		/* display startpos-th element in i-th row of window */
-		highlight(i, filei[startpos], 1); 
+		highlight(i, filei[startpos], 1);
 
-		/* file name is displayed, so we could just go to next iteration, 
+		/* file name is displayed, so we could just go to next iteration,
 		 * but let's display some additional file info (in the same row) */
 		if (filei[startpos].type == 0) { /* let user know that this is a dir */
 			wattrset(addwinlist, A_BOLD | COLOR_PAIR(2));
@@ -927,8 +863,8 @@ void scroll_addlist(WINDOW *addwinlist, int menupos, fileitem *filei, int maxfil
 		} else if (filei[startpos].type == 1) { /* show file size (human readable) */
 			wattrset(addwinlist, COLOR_PAIR(2));
 			mvwprintw(addwinlist, i, getmaxx(addwinlist) - 5, "%4d%s",
-					(filei[startpos].size / 1024 / 1024 > 1 ? 
-						filei[startpos].size / 1024 / 1024 : 
+					(filei[startpos].size / 1024 / 1024 > 1 ?
+						filei[startpos].size / 1024 / 1024 :
 						filei[startpos].size / 1024), (filei[startpos].size / 1024 / 1024 > 1 ? "M" : "K"));
 		}
 	}
@@ -938,32 +874,6 @@ void scroll_addlist(WINDOW *addwinlist, int menupos, fileitem *filei, int maxfil
 
 
 
-/*
- * Draw nice box around window, with label on top and (maybe) bottom of window
- *
- * \param WINDOW *window - ncurses window to be boxed
- * \param char *top_string - string that will appear on top of window
- * \param char *bottom_string - string that will appear on bottom of window
- * \param int width - width of window, can be 0 if bottom_string == ""; 
- * 		FIXME - can width can be guessed from window?
- *
- */
-void nice_box(WINDOW *window, char *top_string, char *bottom_string, int width)
-{
-
-	box(window, 0, 0);
-	if (strcmp(bottom_string, "")) {
-		// add additinal window information 
-		mvwprintw(window, width - 1, 2, "( %s )", bottom_string);
-	}
-	mvwaddch(window, 0, 2, ACS_RTEE);
-
-	// add window title
-	mvwprintw(window, 0, 3, " %s ", top_string);
-	waddch(window, ACS_LTEE);
-
-	return;
-}
 
 
 
@@ -972,7 +882,7 @@ int cdw_title_init(void)
 {
 	int title_len = strlen(PACKAGE) + 2 + strlen(VERSION) + 9;
 	TITLE = (char *) malloc(title_len);
-	sprintf(TITLE, "::: %s-%s :::", PACKAGE, VERSION);
+	sprintf(TITLE, _("::: %s-%s :::"), PACKAGE, VERSION);
 
 	return 0;
 }
@@ -1010,12 +920,12 @@ int cdw_curses_init(void)
 /*
  * Remove menu containing paths selected for recording to CD
  *
- * Remove menu in central part of cdw window. This function is 
- * called either when user adds/removes files to list (every time 
- * new list (in fact: ncurses menu) is allocated, so previous 
+ * Remove menu in central part of cdw window. This function is
+ * called either when user adds/removes files to list (every time
+ * new list (in fact: ncurses menu) is allocated, so previous
  * version must be cleaned up) or at the end of the program.
  */
-void clean_cdmenu(void)
+void cdmenu_clean(void)
 {
 	int i;
 	if (cdmenu != NULL) {
@@ -1027,7 +937,7 @@ void clean_cdmenu(void)
 			free_item(cditems[i]);
 			cditems[i] = NULL;
 		}
-			
+
 		if (cditems != NULL ){
 			free(cditems);
 			cditems = NULL;
@@ -1047,17 +957,17 @@ void clean_cdmenu(void)
 /*
  * Remove menu containing cdw commands
  *
- * Remove menu in left part of cdw window. This function is 
+ * Remove menu in left part of cdw window. This function is
  * called at the end of the program.
  */
-void clean_menu(void)
+void menu_clean(void)
 {
 	int i;
 	if (menu != NULL) {
 		unpost_menu(menu);
 		free_menu(menu);
 		menu = NULL;
-	
+
 		for (i = 0; i < MENU_ITEMS; ++i){
 			free_item(items[i]);
 			items[i] = NULL;
@@ -1067,7 +977,7 @@ void clean_menu(void)
 		items = NULL;
 
 		/* we don't free cdw menu labels since they are static */
-	}	
+	}
 	return;
 }
 
@@ -1091,7 +1001,7 @@ int check_for_boot_image(void)
 
 	sprintf(bootimage, "%s/.cdw/%s", getenv("HOME"), config.bootimg);
 	if ((isofile = fopen(bootimage, "r")) == NULL) {
-		boot_exists = dialogbox(_("Boot image doesn'n exists!"), _("Boot image error"), 0);
+		boot_exists = dialogbox( _("Boot image error"), _("Boot image doesn't exists!"), 0);
 		boot_exists = 0; /* FIXME - why we are assigning 0 here? */
 		/// wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
 		/// select_window(FALSE);
@@ -1108,8 +1018,8 @@ int check_for_boot_image(void)
 /*
  * Fill list with file names, types and sizes of files in given dir
  *
- * Fill custom data structure: list of items, each containing information 
- * about file: name, size and type. So in fact - extract some information 
+ * Fill custom data structure: list of items, each containing information
+ * about file: name, size and type. So in fact - extract some information
  * about current dir that is stored in struct dirent **eps.
  *
  * \param char *dir
@@ -1126,17 +1036,22 @@ int fill_filelist(char *dir, fileitem **filei, struct dirent **eps, int n)
 	bool failure = false;
 	int rv = 0;
 
-	/* Here we have two for loops - first checks if eps item 
+	/* Here we have two for loops - first checks if eps item
 	 * is a DIR - so we will have directories on top of list.
 	 * Then second looks for files. Common counter (pos) ensures that we will
 	 * check all items of eps. */
 	/* FIXME - I'm sure that filei can be handled more elegantly */
 	int i;
 	for (i = 0; i < n; ++i) {
-		if ( (rv = check_fullpath_dir(dir, eps[i]->d_name, &stbuf)) == -1) {
+		char *fullpath = concat(dir, "/", eps[i]->d_name, NULL);
+		rv = is_valid_path(fullpath, -1, CDW_DIR, &stbuf);
+		if (rv == -1) {
+			free(fullpath);
 			failure = true;
-			break;
+			continue; /* don't break this loop - this may be a file */
 		}
+		free(fullpath);
+
 		if (((stbuf.st_mode & S_IFMT) == S_IFDIR) && (strcmp(eps[i]->d_name, ".") != 0)) {
 			strcpy((*filei)[pos].filename, eps[i]->d_name);
 			(*filei)[pos].size = 0;
@@ -1145,10 +1060,15 @@ int fill_filelist(char *dir, fileitem **filei, struct dirent **eps, int n)
 		}
 	}
 	for (i = 0; i < n; ++i) {
-		if ( (rv = check_fullpath_dir(dir, eps[i]->d_name, &stbuf)) == -1) {
+		char *fullpath = concat(dir, "/", eps[i]->d_name, NULL);
+		rv = is_valid_path(fullpath, -1, CDW_FILE, &stbuf);
+		if (rv == -1) {
+			free(fullpath);
 			failure = true;
-			break;
+			continue; /* don't break this loop - this may be a dir */
 		}
+		free(fullpath);
+
 		if ((stbuf.st_mode & S_IFMT) != S_IFDIR) {
 			strcpy((*filei)[pos].filename, eps[i]->d_name);
 			(*filei)[pos].size = stbuf.st_size;
@@ -1172,23 +1092,25 @@ int blank_method_selector(void)
 	WINDOW *blankwin;
 	int ch = 0;
 
+	/* dialog window */
 	blankwin = newwin(10, 30, (LINES - 10) / 2, (COLS - 30) / 2);
 	wbkgd(blankwin, COLOR_PAIR(2));
 	werase(blankwin);
-	keypad(blankwin, true); // enable arrow keys and other keys
+	keypad(blankwin, true); /* enable arrow keys and other keys for this window */
+	nice_box(blankwin, _("Blanking method"), "");
 
-	nice_box(blankwin, _("Blanking method"), "", 0);
-	
-	mvwprintw(blankwin, 2, 3, _("Select cd blanking method"));
-	mvwprintw(blankwin, 4, 5, "1 - fast");
-	mvwprintw(blankwin, 5, 5, "2 - all");
+	/* label and kind-of radio buttons in dialog windows */
+	mvwprintw(blankwin, 2, 3, _("Select CD blanking method"));
+	mvwprintw(blankwin, 4, 5, _("1 - fast"));
+	mvwprintw(blankwin, 5, 5, _("2 - all"));
 
 
+	/* both radiobuttons are blank, preselect one of them based on current configuration */
 	if ( !strcmp(config.blank, "fast") ) {
 		mvwaddch(blankwin, 4, 3, '*');
 	} else if ( !strcmp(config.blank, "all") ) {
 		mvwaddch(blankwin, 5, 3, '*');
-	} else {
+	} else { /* default will be "fast" */
 		mvwaddch(blankwin, 4, 3, '*');
 	}
 
@@ -1210,10 +1132,10 @@ int blank_method_selector(void)
 			}
 		} else if ( ch == KEY_LEFT || ch == KEY_RIGHT ) { // user might want to use these, but don't react
 			;
-		} else if ( ch == 27 || ch == 'q' || ch == 'Q') { // escape, quit
-			return -1;
-		} else if ( ch == 10 ) { // enter
-			return 0;
+		} else if ( ch == CDW_ESCAPE || ch == 'q' || ch == 'Q') {
+			return CDW_ESCAPE;
+		} else if ( ch == CDW_ENTER ) {
+			return CDW_ENTER;
 		} else {
 			; // FIXME - should this be left empty?
 		}
@@ -1229,7 +1151,7 @@ int blank_method_selector(void)
 		}
 		wrefresh(blankwin);
 	}
-	write_conf(config);
+	write_conf();
 
 	delwin(blankwin);
 	return -1;
@@ -1238,207 +1160,29 @@ int blank_method_selector(void)
 
 
 
-/*
- * Show dialog window with message and buttons
+/**
+ * Ask user for volume label
  *
- * Show dialog window with title and message. Depending on type of dialog 
- * user is presented with one, two or three buttons: value of 
- * parameter 'type' describes them. Function returns value of selected button.
- * Background color depends on 'type' value: it is red for 'OK/Cancel' and
- * 'Yes/No/Cancel' dialogs and gray for 'Ok' dialog.
+ * Check if user has to be asked for volume label. Show input dialog if
+ * this is the case. Save volume label in config variable.
  *
- * FIXME: 'Enter' behaviour is not described
- *
- * \param char *message - message displayed in dialog window
- * \param char *title - dialog window title
- * \param int type - type of dialog - values defined in header
- * \returns value of pressed button (valid values defined in header)
+ * \returns CDW_ENTER if user entred volume label (or accepted default value)  and pressed enter;
+ *          CDW_ENTER if user should not be asked for volume label; (default value should be used)
+ *          CDW_ESCAPE if user pressed escape when asked for volume label
  */
-int dialogbox(char *message, char *title, int type)
+int conditional_volume_label_dialog(void)
 {
-	WINDOW *dialog;
-	int line=3, n, i, c, bg_color;
-	
-	// initial dialog WINDOW size: maxwidth and maxline
-	int maxline=0, maxwidth=30;
+	int rv = 0;
 
-	char temp[50];
+	if (strcmp(config.showvol, "1") == 0) { /* ask for disk label */
+		rv = input_box(_("Volume ID"), _("Enter volume label:"), config.volumeid, 0);
+		wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
+		select_window(TRUE);
 
-	int button; // current button
-	// initial button = OK/YES
-	if (type == DIALOG_YES_NO_CANCEL) {
-		button = BUTTON_YES;
-	} else { // DIALOG_OK_CANCEL or DIALOG_OK, BUTTON_OK wil be default in both cases
-		button = BUTTON_OK;
-	}
-	
-	/* recalculate window size */
-	temp[0] = '\0'; 
-	n = 0;
-	for (i = 0; i < strlen(message); i++){
-		if (message[i] != '\n') 
-			temp[n++] = message[i];
-		if (( message[i] == '\n') || (i == strlen(message) - 1) || ((n > 30) && message[i] == ' ')){
-			temp[n] = '\0';
-			if (maxwidth < strlen(temp) + 8) {
-				maxwidth = strlen(temp) + 8;
-			}
-			temp[0] = '\0';
-			n = 0;
-			if (message[i] == '\n') {
-				maxline++;
-			}
+		if (rv == CDW_ESCAPE) {
+			return CDW_ESCAPE;
 		}
 	}
 
-	switch (type){
-		case DIALOG_OK:
-			bg_color = 2;
-			break;
-		case DIALOG_OK_CANCEL:
-		case DIALOG_YES_NO_CANCEL:
-			bg_color = 10;
-			break;
-	}
-
-	dialog = newwin(9 + maxline, maxwidth, (LINES - (9 + maxline)) / 2, (COLS - maxwidth) / 2);
-	wbkgd(dialog, COLOR_PAIR(bg_color));
-	werase(dialog);
-	nice_box(dialog, title, "", 0);
-	keypad(dialog, TRUE);
-	
-	/* wrap message text so that it fits into dialog window;
-	 * print each wrapped line into dialog window */
-	temp[0] = '\0'; 
-	n = 0;
-	for (i = 0; i < strlen(message); i++){
-		if (message[i] != '\n') 
-			temp[n++] = message[i];
-		if ((message[i] == '\n') || (i == strlen(message) - 1) || ((n > 30) && message[i] == ' ')){
-			temp[n] = '\0';
-			mvwprintw(dialog, line++, (maxwidth - strlen(temp)) / 2, temp);
-			temp[0] = '\0';
-			n = 0;
-		}
-	}
-
-	// buttons positions
-	// buttons are in one row
-	int buttons_row = maxline + 6;
-	// 1-button dialog
-	int ok_col_1 = (getmaxx(dialog) - strlen(_("Ok"))) / 2;
-	// 2-button dialog
-	int ok_col_2 = 8;
-	int cancel_col_2 = (maxwidth - 7) - strlen(_("Cancel"));
-	// 3-button dialog
-	int yes_col_3 = 4; 
-	int no_col_3 = 14; 
-	int cancel_col_3 = (maxwidth - 7) - strlen(_("Cancel"));
-
-	/* draw initial dialog box */
-	if (type == DIALOG_OK) {
-		wattrset(dialog, COLOR_PAIR(6));	
-		mvwprintw(dialog, buttons_row, ok_col_1	, "[ %s ]", _("Ok"));
-	}
-	if (type == DIALOG_OK_CANCEL) {
-		wattrset(dialog, COLOR_PAIR(6));	
-		mvwprintw(dialog, buttons_row, ok_col_2, "[ %s ]", _("Ok"));
-
-		wattrset(dialog, COLOR_PAIR(bg_color));	
-		mvwprintw(dialog, buttons_row, cancel_col_2, "[ %s ]", _("Cancel"));
-	}
-	if (type == DIALOG_YES_NO_CANCEL) {
-		wattrset(dialog, COLOR_PAIR(6));	
-		mvwprintw(dialog, buttons_row, yes_col_3, "[ %s ]", _("Yes"));
-
-		wattrset(dialog, COLOR_PAIR(bg_color));	
-		mvwprintw(dialog, buttons_row, no_col_3, "[ %s ]", _("No"));
-
-		wattrset(dialog, COLOR_PAIR(bg_color));	
-		mvwprintw(dialog, buttons_row, cancel_col_3, "[ %s ]", _("Cancel"));
-	}
-	wrefresh(dialog);
-
-	/* handle cursor keys */
-	while (((c = mvwgetch(dialog, 8 + maxline, maxwidth - 1)) != 27) && (c != 10)) {
-		/* select action according to dialog type,
-		 * key pressed and currently selected button */
-		if (type == DIALOG_OK_CANCEL) {
-			switch(c){
-			case KEY_RIGHT:
-				if (button == BUTTON_OK){
-					wattrset(dialog, COLOR_PAIR(bg_color));	
-					mvwprintw(dialog, buttons_row, ok_col_2, "[ %s ]", _("Ok"));
-					wattrset(dialog, COLOR_PAIR(6));	
-					mvwprintw(dialog, buttons_row, cancel_col_2, "[ %s ]", _("Cancel"));
-					button = BUTTON_CANCEL;
-				}
-				break;
-			case KEY_LEFT:
-				if (button == BUTTON_CANCEL){
-					wattrset(dialog, COLOR_PAIR(6));	
-					mvwprintw(dialog, buttons_row, ok_col_2, "[ %s ]", _("Ok"));
-					wattrset(dialog, COLOR_PAIR(bg_color));	
-					mvwprintw(dialog, buttons_row, cancel_col_2, "[ %s ]", _("Cancel"));
-					button = BUTTON_OK;
-				}
-				break;
-			}
-		} else 	if (type == DIALOG_YES_NO_CANCEL) {
-			switch(c){
-			case KEY_RIGHT:
-				if (button == BUTTON_YES){
-					wattrset(dialog, COLOR_PAIR(bg_color));	
-					mvwprintw(dialog, buttons_row, yes_col_3, "[ %s ]", _("Yes"));
-					wattrset(dialog, COLOR_PAIR(6));	
-					mvwprintw(dialog, buttons_row, no_col_3, "[ %s ]", _("No"));
-					button = BUTTON_NO;
-				} else 	if (button == BUTTON_NO){
-					wattrset(dialog, COLOR_PAIR(bg_color));	
-					mvwprintw(dialog, buttons_row, no_col_3, "[ %s ]", _("No"));
-					wattrset(dialog, COLOR_PAIR(6));	
-					mvwprintw(dialog, buttons_row, cancel_col_3, "[ %s ]", _("Cancel"));
-					button = BUTTON_CANCEL;
-				} else 	if (button == BUTTON_CANCEL){
-					wattrset(dialog, COLOR_PAIR(bg_color));	
-					mvwprintw(dialog, buttons_row, cancel_col_3, "[ %s ]", _("Cancel"));
-					wattrset(dialog, COLOR_PAIR(6));	
-					mvwprintw(dialog, buttons_row, yes_col_3, "[ %s ]", _("Yes"));
-					button = BUTTON_YES;
-				}
-				break;
-			case KEY_LEFT:
-				if (button == BUTTON_YES){ // yes -> cancel
-					wattrset(dialog, COLOR_PAIR(bg_color));	
-					mvwprintw(dialog, buttons_row, yes_col_3, "[ %s ]", _("Yes"));
-					wattrset(dialog, COLOR_PAIR(6));	
-					mvwprintw(dialog, buttons_row, cancel_col_3, "[ %s ]", _("Cancel"));
-					button = BUTTON_CANCEL;
-				} else if (button == BUTTON_NO){ // no -> yes
-					wattrset(dialog, COLOR_PAIR(bg_color));	
-					mvwprintw(dialog, buttons_row, no_col_3, "[ %s ]", _("No"));
-					wattrset(dialog, COLOR_PAIR(6));	
-					mvwprintw(dialog, buttons_row, yes_col_3, "[ %s ]", _("Yes"));
-					button = BUTTON_YES;
-				} else 	if (button == BUTTON_CANCEL){ // cancel -> no
-					wattrset(dialog, COLOR_PAIR(bg_color));	
-					mvwprintw(dialog, buttons_row, cancel_col_3, "[ %s ]", _("Cancel"));
-					wattrset(dialog, COLOR_PAIR(6));	
-					mvwprintw(dialog, buttons_row, no_col_3, "[ %s ]", _("No"));
-					button = BUTTON_NO;
-				}
-				break;
-			} // switch
-		} // if
-		wrefresh(dialog);
-	} // while
-
-	if (c == 27) {
-		button = 1;
-	}
-
-	delwin(dialog);
-	wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
-	select_window(FALSE);
-	return button;
+	return CDW_ENTER;
 }
