@@ -2,7 +2,7 @@
 #define __COMMANDS_H
 
 
-/* functions preparing string with program name and it's 
+/* functions preparing string with program name and it's
  * arguments and calling run_command() */
 int run_command_create_image(void);
 int run_command_write_from_image(void);
@@ -11,6 +11,8 @@ int run_command_write_audio(void);
 int run_command_copy_disk(void);
 int run_command_blank_cd(void);
 
+int run_command_check_erasable(void);
+
 
 int prepare_createiso_command(char *command, char *iso_file);
 void prepare_writetoCD_command(char *command);
@@ -22,4 +24,4 @@ enum media_erasable_t {
 	MEDIA_ERASABLE_NO
 };
 
-#endif // __COMMANDS_H
+#endif /* __COMMANDS_H */
