@@ -90,7 +90,7 @@ void gtk_error_dialog(char *message)
 {
     GtkWidget *dialog;
     gint result;
-    
+
     dialog = gtk_message_dialog_new(GTK_WINDOW(window1), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, message);
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
     result=gtk_dialog_run(GTK_DIALOG(dialog));
@@ -102,7 +102,7 @@ int connect_database_gtk()
     char message[200];
     GtkWidget *dialog;
     gint result;
-   
+
 #ifdef HAVE_LIBMYSQLCLIENT
     mysql_init(&mysql);
     if (!mysql_real_connect(&mysql, config.cdbhost, config.cdbuser, cdbpass, "cdw", 0, NULL, 0)){
@@ -113,7 +113,7 @@ int connect_database_gtk()
     if (!sqlite_db) {
 	sprintf(message, "%s", errmsg);
 #endif
-	if (strlen(message)<=0) 
+	if (strlen(message)<=0)
 	    sprintf(message, _("Unknown error! Check the settings!"));
 	dialog = gtk_message_dialog_new(GTK_WINDOW(window1), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, message);
 	gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
@@ -127,7 +127,7 @@ int connect_database_gtk()
 void insert_disk_gtk(char *disk, char *cd_num, char *type)
 {
     int id;
-    
+
     if (switch_type((char *)type)==0){
 	add_type((char *)type);
     }
@@ -140,7 +140,7 @@ int add_to_dic_gtk()
     char cdname[60], category[60], cd_num[5], command[255], cmd[255];
     int ret;
     gboolean passwd_entered;
-	
+
 #ifdef HAVE_LIBMYSQLCLIENT
     if (strlen(cdbpass)<=0) {
 	strcpy(cdbpass, "\0");
@@ -214,7 +214,7 @@ int load_disk_gtk(char *type, char *diskname, char* dir)
 #endif
     int c=0, i, found, count, forcounter;
     char *line, itemname[100];
-    char *linestr; 
+    char *linestr;
     char *column[2];
 
     file_list_gtk[0].cd_num=0;
@@ -254,7 +254,7 @@ int load_disk_gtk(char *type, char *diskname, char* dir)
 	//sqlite_free_table(disk->result);
 	sqlite_close(sqlite_db);
 #endif
-    }    
+    }
     if (dir_level==1) {
 	char num[6];
 	if ( (search_gtk!=1) && ((disk=query_disk(diskname, 0, type))!=NULL) ) {
@@ -325,7 +325,7 @@ int load_disk_gtk(char *type, char *diskname, char* dir)
 	sqlite_free_table(result->result);
 	sqlite_close(sqlite_db);
 #endif
-    }    
+    }
     if (dir_level>=2) {
 	if (search_gtk==1){
 	    disk=search_content(file, type, diskname, dir);
@@ -426,7 +426,7 @@ void status_line_gtk(struct file_list_struct info)
     char page_str[10];
     char dir_str[255];
     char settext[255];
-    
+
     switch (info.type) {
 	case 0:
 	    strcpy(str, "Type");
@@ -441,7 +441,7 @@ void status_line_gtk(struct file_list_struct info)
 	    strcpy(str, "File");
 	    break;
     }
-    if (search_gtk==1) 
+    if (search_gtk==1)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_search), TRUE);
     else
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_search), FALSE);
@@ -512,7 +512,7 @@ void go_up(GtkWidget *widget, gpointer *user_data)
     else if (dir_level>3) {
 	char *dir;
 	char *line;
-	
+
 	dir_level--;
 	for (i=0; i<4; i++)
 	    gtk_label_set_text(GTK_LABEL(labels[i]), "");
@@ -620,7 +620,7 @@ int search_in_dic_gtk()
 	   sprintf(var_disk, "*");
 	   sprintf(var_dir, "*");
 	   i=load_disk_gtk("*", "*", "*");
-	   list_index=0;    
+	   list_index=0;
 	   status_line_gtk(file_list_gtk[list_index]);
 	} else {
 	    dir_level=1;
@@ -633,8 +633,8 @@ int search_in_dic_gtk()
 	    sprintf(var_disk, "*");
 	    sprintf(var_dir, "*");
 	    i=load_disk_gtk("*", "*", "*");
-	    list_index=0;    
-	    status_line_gtk(file_list_gtk[list_index]);	    
+	    list_index=0;
+	    status_line_gtk(file_list_gtk[list_index]);
 	}
     }
 }
@@ -642,7 +642,7 @@ int search_in_dic_gtk()
 void delete_from_db_gtk(struct file_list_struct info)
 {
     int cd_id;
-    
+
     if (dir_level==1) {
 	cd_id=delete_disk(info.files, info.cd_num, info.type_name);
 	delete_content(cd_id);
@@ -709,8 +709,8 @@ int cddb_window_gtk(GtkWidget *widget, gpointer user_data)
     int i;
     gboolean result;
     gboolean passwd_entered;
-    
-    config=read_conf();
+
+    read_conf();
     strcpy(cdbpass, "\0");
     sprintf(msg, "%s %s", config.cdbuser, _("password"));
 #ifdef HAVE_LIBMYSQLCLIENT
@@ -723,7 +723,7 @@ int cddb_window_gtk(GtkWidget *widget, gpointer user_data)
 	dialog=gtk_dialog_new_with_buttons(_("Disk catalog"), GTK_WINDOW(window1), GTK_DIALOG_MODAL, GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT, NULL);
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 580, 440);
 	main_vbox=gtk_vbox_new(FALSE, 1);
-	
+
 	toolbar=gtk_toolbar_new();
 	gtk_box_pack_start(GTK_BOX(main_vbox), toolbar, FALSE, FALSE, 0);
 	gtk_widget_show(toolbar);
@@ -733,7 +733,7 @@ int cddb_window_gtk(GtkWidget *widget, gpointer user_data)
 	add_toolbar_item(toolbar, _("Search"), _("Search files and directories"), "search.png", 2, toolbar_images[2], toolbar_items[2], GTK_SIGNAL_FUNC(search_in_dic_gtk));
 	add_toolbar_item(toolbar, _("Delete"), _("Delete selected item"), "delete.png", 3, toolbar_images[3], toolbar_items[3], GTK_SIGNAL_FUNC(delete_gtk));
 	add_toolbar_item(toolbar, _("Up"), _("Go up one level"), "up.png", 4, toolbar_images[4], toolbar_items[4], GTK_SIGNAL_FUNC(go_up));
-	
+
 	hbox=gtk_hbox_new(FALSE, 2);
 	for (i=0; i<3; i++)
 	    vbox[i]=gtk_vbox_new(FALSE, 0);
@@ -769,7 +769,7 @@ int cddb_window_gtk(GtkWidget *widget, gpointer user_data)
 	gtk_container_add(GTK_CONTAINER(main_vbox), hbox);
 	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), main_vbox);
 	gtk_widget_show_all(dialog);
-	
+
 	dir_level=0;
 	if (connect_database()!=0){
 	    gtk_widget_destroy(dialog);
