@@ -68,7 +68,7 @@ gboolean gtk_input(char *title, char *msg, char *text, int size, gboolean is_pas
 {
     GtkWidget *dialog, *label, *entry;
     gint result;
-    
+
     dialog = gtk_dialog_new_with_buttons(title, GTK_WINDOW(window1), GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
     label = gtk_label_new(msg);
@@ -98,7 +98,7 @@ gboolean gtk_message(char *msg)
 {
     GtkWidget *dialog;
     gint result;
-    
+
     dialog = gtk_message_dialog_new(GTK_WINDOW(window1), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, msg);
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
     result=gtk_dialog_run(GTK_DIALOG(dialog));
@@ -117,7 +117,7 @@ gboolean gtk_error_message(char *msg)
 {
     GtkWidget *dialog;
     gint result;
-    
+
     dialog = gtk_message_dialog_new(GTK_WINDOW(window1), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK, msg);
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
     result=gtk_dialog_run(GTK_DIALOG(dialog));
@@ -131,7 +131,7 @@ gboolean help_win_gtk(GtkWidget *widget, gpointer user_data)
     gint result, i;
     GtkTextBuffer *buffer;
     char imagefile[255], title[20];
-    
+
     dialog = gtk_dialog_new_with_buttons(_("About"), GTK_WINDOW(window1), GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
     gtk_window_set_default_size (GTK_WINDOW(dialog), 400, 300);
     //gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
@@ -160,7 +160,7 @@ gboolean help_win_gtk(GtkWidget *widget, gpointer user_data)
     gtk_text_buffer_insert_at_cursor(buffer, "  modify it under the terms of the GNU General Public License\n", -1);
     gtk_text_buffer_insert_at_cursor(buffer, "\n", -1);
     gtk_text_buffer_insert_at_cursor(buffer, "Homepage: http://cdw.sourceforge.net\n", -1);
-    
+
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), frame, FALSE, TRUE, 0);
     gtk_container_add(GTK_CONTAINER(frame), vbox);
     gtk_box_pack_start(GTK_BOX(vbox), image, FALSE, FALSE, 0);
@@ -171,7 +171,7 @@ gboolean help_win_gtk(GtkWidget *widget, gpointer user_data)
     gtk_container_add(GTK_CONTAINER(scroll), view);
     gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), scroll);
     gtk_widget_show_all(GTK_DIALOG(dialog)->vbox);
-    
+
     gtk_widget_show_all(dialog);
     result=gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy(dialog);
@@ -193,7 +193,7 @@ void text_dialog(char *title, char *command, char *file)
     GtkTextBuffer *buffer;
     gsize *bytes_read, *bytes_written;
     int i;
-    
+
     dialog = gtk_dialog_new_with_buttons(title, GTK_WINDOW(window1), GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
     scroll=gtk_scrolled_window_new(NULL, NULL);
     gtk_window_set_default_size (GTK_WINDOW(dialog), 400, 300);
@@ -232,13 +232,13 @@ void show_cd_info_gtk(GtkWidget *widget, gpointer user_data)
 void volume_id_gtk(GtkWidget *widget, gpointer user_data)
 {
     gtk_input(_("Volume ID"), _("Enter volume label:"), config.volumeid, 40, FALSE);
-    write_conf(config);
+    write_conf();
 }
 
 void parameters_gtk(GtkWidget *widget, gpointer user_data)
 {
     gtk_input(_("CD record parameters"), _("Enter parameter:"), config.other, 255, FALSE);
-    write_conf(config);
+    write_conf();
 }
 
 gboolean select_size_gtk(GtkWidget *widget, gpointer user_data)
@@ -246,7 +246,7 @@ gboolean select_size_gtk(GtkWidget *widget, gpointer user_data)
     GtkWidget *dialog, *radio[4], *frame, *vbox1;
     gint result, i;
     gchar sizestr[5];
-    
+
     dialog = gtk_dialog_new_with_buttons(_("CD size"), GTK_WINDOW(window1), GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
     radio[0]=gtk_radio_button_new_with_label(NULL, "74 Min (650 MB)");
     radio[1]=gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON(radio[0]), "80 Min (700 MB)");
@@ -292,7 +292,7 @@ gboolean select_size_gtk(GtkWidget *widget, gpointer user_data)
 		config.cdsize=4700;
 	    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio[3])))
 		config.cdsize=atoi(gtk_entry_get_text(GTK_ENTRY(size_entry)));
-	    write_conf(config);
+	    write_conf();
 	    gtk_widget_destroy(dialog);
 	    select_window_gtk(TRUE);
 	    return TRUE;
@@ -304,7 +304,7 @@ gboolean select_size_gtk(GtkWidget *widget, gpointer user_data)
     }
 }
 
-void eject_gtk(GtkWidget *widget, gpointer user_data) 
+void eject_gtk(GtkWidget *widget, gpointer user_data)
 {
     eject_tray(config.cdrwdevice);
 }
@@ -326,10 +326,10 @@ void after_event_gtk(char *message, int adddic){
     }
 }
 
-void browse_store_filename(GtkWidget *widget, gpointer user_data) 
+void browse_store_filename(GtkWidget *widget, gpointer user_data)
 {
     const gchar *selected_filename;
-    
+
     gtk_entry_set_text(GTK_ENTRY(user_data), gtk_file_selection_get_filename(GTK_FILE_SELECTION(fileselect)));
 }
 
@@ -384,7 +384,7 @@ void encode_toggled(GtkWidget *widget, gpointer user_data)
 #endif
 #ifdef LAME
 	gtk_widget_set_sensitive(radio_frame, TRUE);
-	if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ogg))) 
+	if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio_ogg)))
 	    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_mp3), TRUE);
 #endif
     } else {
@@ -410,18 +410,18 @@ void multi_toggled(GtkWidget *widget, gpointer user_data)
 	gtk_widget_set_sensitive(check_image, TRUE);
 }
 
-gboolean options_gtk(GtkWidget *widget, gpointer user_data) 
+gboolean options_gtk(GtkWidget *widget, gpointer user_data)
 {
     GtkWidget *dialog, *tab_label[2], *entry, *page[2], *tab, *hbox[2], *vbox[4];
     gint i, result;
     GtkBoxChild *gchild;
     gdouble speed;
-    
+
     dialog = gtk_dialog_new_with_buttons(_("Options"), GTK_WINDOW(window1), GTK_DIALOG_MODAL, GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
     page[0] = gtk_frame_new(NULL);
     page[1] = gtk_frame_new(NULL);
-    
+
     for (i=0; i<2; i++)
 	hbox[i]=gtk_hbox_new(FALSE, 5);
     for (i=0; i<4; i++)
@@ -505,7 +505,7 @@ gboolean options_gtk(GtkWidget *widget, gpointer user_data)
     gtk_box_pack_start(GTK_BOX(vbox[3]), check_sound, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox[3]), label_bps, FALSE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(vbox[3]), radio_frame, FALSE, FALSE, 0);
-   
+
     /*** FILL DATA ***/
     gchild=GTK_BOX(label_SCSI)->children->next->data;
     gtk_entry_set_text(GTK_ENTRY(gchild->widget), config.scsi);
@@ -539,7 +539,7 @@ gboolean options_gtk(GtkWidget *widget, gpointer user_data)
     gtk_entry_set_text(GTK_ENTRY(gchild->widget), config.cdbuser);
     gtk_widget_set_sensitive(label_sqlite_file, FALSE);
     gtk_widget_set_sensitive(label_sqlite_file, FALSE);
-#else 
+#else
 #ifndef HAVE_LIBSQLITE
     gtk_widget_set_sensitive(label_mnt, FALSE);
     gtk_widget_set_sensitive(check_autodic, FALSE);
@@ -595,19 +595,19 @@ gboolean options_gtk(GtkWidget *widget, gpointer user_data)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_sound), TRUE);
     if ( strncmp(config.highq,"1",strlen(config.highq))==0)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_high), TRUE);
-    
-#ifdef OGGENC	
+
+#ifdef OGGENC
     if ( strncmp(config.encode,"1",strlen(config.encode))==0){
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_ogg), TRUE);
     }
 #else
     gtk_widget_set_sensitive(radio_ogg, FALSE);
-#endif	
-   
+#endif
+
 #ifdef LAME
    if ( strncmp(config.lame,"1",strlen(config.lame))==0){
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_mp3), TRUE);
-   }	
+   }
 #else
     gtk_widget_set_sensitive(radio_mp3, FALSE);
 #endif
@@ -625,7 +625,7 @@ gboolean options_gtk(GtkWidget *widget, gpointer user_data)
     gtk_signal_connect(GTK_OBJECT(check_image), "toggled", G_CALLBACK(image_toggled), NULL);
     gtk_signal_connect(GTK_OBJECT(check_multi), "toggled", G_CALLBACK(multi_toggled), NULL);
     /*****************/
-    
+
     gtk_box_pack_start(GTK_BOX(hbox[0]), vbox[0], TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(hbox[0]), vbox[1], TRUE, TRUE, 0);
     gtk_box_pack_start(GTK_BOX(hbox[1]), vbox[2], TRUE, TRUE, 0);
@@ -701,7 +701,7 @@ gboolean options_gtk(GtkWidget *widget, gpointer user_data)
 		sprintf(config.encode, "%d", 0);
 		sprintf(config.lame, "%d", 0);
 	    }
-	    write_conf(config);
+	    write_conf();
 	    gtk_widget_destroy(dialog);
 	    fill_info_gtk();
 	    return TRUE;
@@ -722,7 +722,7 @@ int one_gtk(struct dirent *unused)
 	return 0;
 }
 
-gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data) 
+gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 {
     GtkWidget *dialog, *label_tracks, *spin_start, *spin_end, *msg;
     GtkWidget *hbox, *vbox[2];
@@ -732,10 +732,10 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
     DIR *directory;
     int start_track=0, end_track=0, max_track=0, tracknum=0;
     GtkBoxChild *gchild;
-    
+
     sprintf(cdinfo,"%s -D%s -J -H -g", CDDA2WAV, config.cdrom);
     run_command_gtk(cdinfo, _("Load CD info..."), 0, 0, 0, "");
-    
+
     if ( (fp=fopen(config.logfile,"r"))==NULL){
 	fprintf(stderr, _("Cannot open file..."));
 	gtk_main_quit();
@@ -757,7 +757,7 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 	gtk_box_pack_start(GTK_BOX(hbox), vbox[i], FALSE, FALSE, 0);
     }
     gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
-    
+
     if (end_track){
 	sprintf(tracks, "%s %d", _("Number of tracks: "), end_track);
 	label_tracks=gtk_label_new(tracks);
@@ -777,7 +777,7 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 	gtk_widget_set_sensitive(spin_start, FALSE);
 	gtk_widget_set_sensitive(spin_end, FALSE);
     }
-    
+
     check_stereo=gtk_check_button_new_with_label(_("Grab stereo mode"));
     check_sound=gtk_check_button_new_with_label(_("Echo to soundcard"));
     check_high=gtk_check_button_new_with_label(_("High quality"));
@@ -810,19 +810,19 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_sound), TRUE);
     if ( strncmp(config.highq,"1",strlen(config.highq))==0)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_high), TRUE);
-    
-#ifdef OGGENC	
+
+#ifdef OGGENC
     if ( strncmp(config.encode,"1",strlen(config.encode))==0){
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_ogg), TRUE);
     }
 #else
     gtk_widget_set_sensitive(radio_ogg, FALSE);
-#endif	
-   
+#endif
+
 #ifdef LAME
    if ( strncmp(config.lame,"1",strlen(config.lame))==0){
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_mp3), TRUE);
-   }	
+   }
 #else
     gtk_widget_set_sensitive(radio_mp3, FALSE);
 #endif
@@ -833,7 +833,7 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 	gtk_widget_set_sensitive(radio_frame, FALSE);
     gtk_signal_connect(GTK_OBJECT(check_encode), "toggled", G_CALLBACK(encode_toggled), NULL);
     /************/
-    
+
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox, TRUE, TRUE, 0);
     gtk_widget_show_all(dialog);
     result=gtk_dialog_run(GTK_DIALOG(dialog));
@@ -871,7 +871,7 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 		    sprintf(config.encode, "%d", 0);
 		    sprintf(config.lame, "%d", 0);
 		}
-		write_conf(config);
+		write_conf();
 		sprintf(cdinfo, "%s ", CDDA2WAV);
 		if ( strncmp(config.stereo,"1", strlen(config.stereo))==0)
 		    sprintf(cdinfo, "%s -s", cdinfo);
@@ -882,7 +882,7 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 		}
 		if ( strncmp(config.encode,"1", strlen(config.encode))==0){
 		    char msg[30];
-#ifdef OGGENC 
+#ifdef OGGENC
 		    sprintf(cmd, "%s", cdinfo);
 		    for (tracknum=start_track; tracknum<=end_track; tracknum++) {
 			if ( strncmp(config.highq,"1", strlen(config.highq))==0){
@@ -893,10 +893,10 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 		       sprintf(msg, _("Track: %d"), tracknum);
 		       run_command_gtk(cdinfo, _("Grab Audio CD"), 0, 0, 1, msg);
 		    }
-#endif			
+#endif
 		} else if ( strncmp(config.lame,"1", strlen(config.lame))==0){
 		    char msg[30];
-#ifdef LAME			  		
+#ifdef LAME
 		    sprintf(cmd, "%s", cdinfo);
 		    for (tracknum=start_track; tracknum<=end_track; tracknum++) {
 			if ( strncmp(config.highq,"1", strlen(config.highq))==0){
@@ -907,7 +907,7 @@ gboolean cdda2wav_gtk(GtkWidget *widget, gpointer user_data)
 			sprintf(msg, _("Track: %d"), tracknum);
 			run_command_gtk(cdinfo, _("Grab Audio CD"), 0, 0, 1, msg);
 		    }
-#endif			
+#endif
 		} else {
 		    char msg[30];
 
@@ -936,7 +936,7 @@ void select_row_gtk(GtkCList *clist, gint row, gint column, GdkEventButton *even
 }
 
 
-void create_image_gtk(GtkWidget *widget, gpointer user_data) 
+void create_image_gtk(GtkWidget *widget, gpointer user_data)
 {
     char command[255];
     gboolean ret=TRUE, exist=TRUE;
@@ -955,7 +955,7 @@ void create_image_gtk(GtkWidget *widget, gpointer user_data)
 	}
 	if ( strlen(config.bootimg) ) {
 	    char bootimage[255];
-	    
+
 	    sprintf(bootimage, "%s/.cdw/%s", getenv("HOME"), config.bootimg);
 	    if ( (isofile=fopen(bootimage, "r"))==NULL ){
 		boot_exists=gtk_error_message(_("Boot image doesn't exist!"));
@@ -981,7 +981,7 @@ void create_image_gtk(GtkWidget *widget, gpointer user_data)
     }
 }
 
-void blank_cdrw_gtk(GtkWidget *widget, gpointer user_data) 
+void blank_cdrw_gtk(GtkWidget *widget, gpointer user_data)
 {
     char command[255];
 
@@ -993,9 +993,9 @@ void copy_image_win_gtk(GtkWidget *widget, gpointer user_data)
 {
     gboolean exist=TRUE;
     FILE *isofile;
-    
+
     if ( (isofile=fopen(config.tempdir, "r"))!=NULL ){
-//       exist=dialogbox(_("Image file exist!\nDo you wish to overwrite it?"), _("Image exist"), 3);
+//       exist=dialogbox(_("Image exist"), _("Image file exist!\nDo you wish to overwrite it?"), 3);
 	exist=gtk_message(_("Image file exist!\nDo you wish to overwrite it?"));
         fclose(isofile);
     }
@@ -1029,7 +1029,7 @@ void write_cd_gtk(GtkWidget *widget, gpointer user_data)
 	char mkisofscmd[255];
 	FILE *isofile;
 	int boot_exists=1;
-	
+
 	gboolean ret=TRUE;
 	if ( strcmp(config.showvol,"1")==0 )
 	    ret=gtk_input(_("Volume ID"), _("Enter volume label:"), config.volumeid, 40, FALSE);
@@ -1046,7 +1046,7 @@ void write_cd_gtk(GtkWidget *widget, gpointer user_data)
 	    }
 	    if ( strlen(config.bootimg) ) {
 		char bootimage[255];
-		
+
 		sprintf(bootimage, "%s/.cdw/%s", getenv("HOME"), config.bootimg);
 		if ( (isofile=fopen(bootimage, "r"))==NULL ){
 		    boot_exists=gtk_error_message(_("Boot image doesn't exist!"));
@@ -1113,7 +1113,7 @@ void write_audio_gtk(GtkWidget *widget, gpointer user_data)
 {
     char command[255];
     gboolean ret=TRUE;
-    
+
     if ( strcmp(config.showvol,"1")==0 )
 	ret=gtk_input((char*)_("Volume ID"), _("Enter volume label:"), config.volumeid, 40, FALSE);
     if (ret) {
@@ -1154,10 +1154,10 @@ void copy_data_gtk(GtkWidget *widget, gpointer user_data)
 	sprintf(command,"%s -isosize %s",command, config.cdrom);
 	run_command_gtk(command, _("Copy data CD"), 0, 1, 1, "");
 	after_event_gtk(_("Copy data CD log"), 1);
-    } 
+    }
 }
 
-void store_filename(GtkWidget *widget, gpointer user_data) 
+void store_filename(GtkWidget *widget, gpointer user_data)
 {
     const gchar *selected_filename;
     char path[2000], linkfile[2000], newlink[2000];
@@ -1166,7 +1166,7 @@ void store_filename(GtkWidget *widget, gpointer user_data)
     char *pos;
     int screenpos;
     GError *err;
-    
+
     selected_filename = gtk_file_selection_get_filename(GTK_FILE_SELECTION(fileselect));
     if (strlen(g_path_get_basename(selected_filename))>0) {
 	sprintf(newlink, "%s/%s", homedir, g_path_get_basename(selected_filename));
@@ -1182,14 +1182,14 @@ void add_files_gtk(GtkWidget *widget, gpointer data)
     g_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(fileselect)->ok_button), "clicked", G_CALLBACK(store_filename), NULL);
     g_signal_connect_swapped(GTK_OBJECT(GTK_FILE_SELECTION(fileselect)->ok_button), "clicked", G_CALLBACK(gtk_widget_destroy), (gpointer)fileselect);
     g_signal_connect_swapped(GTK_OBJECT(GTK_FILE_SELECTION(fileselect)->cancel_button), "clicked", G_CALLBACK(gtk_widget_destroy), (gpointer)fileselect);
-    gtk_widget_show(fileselect); 
+    gtk_widget_show(fileselect);
 }
 
 void delete_files_gtk(GtkWidget *widget, gpointer data)
 {
     int c;
     char filetodelete[255]="\0";
-    
+
     if (rowindex>=0){
 	strcpy(filetodelete, homedir);
 	strcat(filetodelete,"/");
@@ -1214,7 +1214,7 @@ double dirsize_gtk(char *dir)
 	    sprintf(ch,"%s/%s",dir,eps[cnt]->d_name);
 	    finfo=(struct stat *)malloc(sizeof(finfo)+100);
 	    ok=lstat(ch,finfo);
-	    if ( (eps[cnt]->d_type=DT_DIR) ) 
+	    if ( (eps[cnt]->d_type=DT_DIR) )
 		dirsize_gtk(ch);
 	    if (ok=stat(ch,finfo)!=0);
 	    else {
@@ -1235,12 +1235,12 @@ void space_gtk(double size)
 
     if (size<=config.cdsize) {
 	percent=(size / ((float)config.cdsize / 100));
-	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(size_bar), percent/100);	
+	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(size_bar), percent/100);
     }
     else {
 	percent=(float)(100);
 //	percent=(size / ((float)config.cdsize / 100));
-	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(size_bar), percent/100);	
+	gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(size_bar), percent/100);
     }
     if ( config.cdsize-size >= 0 ) {
 	sprintf(wasted_msg, _("Used: %2.1f%%, Wasted: %.0f/%d MB"), percent, config.cdsize-size,config.cdsize);
@@ -1259,7 +1259,7 @@ int select_window_gtk(bool real)
     struct stat *finfo;
     int ok, err, fsize;
     char *ch;
-    
+
     if (real==TRUE) {
 	gtk_clist_clear(GTK_CLIST(filelist));
 	num = scandir(homedir, &cdfiles, (void *)one_gtk, alphasort);
@@ -1296,22 +1296,22 @@ int select_window_gtk(bool real)
     }
     size_gtk=0;
     sprintf(msg_text, _("Size: %.0f Mb in %d files"), dirsize_gtk(homedir)/1024/1024, num);
-    gtk_label_set_text(GTK_LABEL(size_msg), msg_text);    
+    gtk_label_set_text(GTK_LABEL(size_msg), msg_text);
     space_gtk(size_gtk/1024/1024);
 }
-    
+
 void fill_info_gtk()
 {
     char speed[30];
     if (strcmp(config.fromimage, "1")==0)
 	gtk_label_set_text(GTK_LABEL(info[0]), _("Write from image"));
-    else 
+    else
 	gtk_label_set_text(GTK_LABEL(info[0]), _("Write direct    "));
     sprintf(speed, "%s %sX", _("Speed:"), config.speed);
     gtk_label_set_text(GTK_LABEL(info[1]), speed);
     if (strcmp(config.multi, "1")==0)
 	gtk_label_set_text(GTK_LABEL(info[2]), _("Multi-session "));
-    else 
+    else
 	gtk_label_set_text(GTK_LABEL(info[2]), _("Single session"));
 }
 
@@ -1343,10 +1343,10 @@ int gtk_gui(int argc, char *argv[])
 
     bind_textdomain_codeset(PACKAGE, "UTF-8");
     gtk_init(0, &argv);
-    
+
     sprintf(homedir,"%.225s/.cdw",getenv("HOME"));
     mkdir(homedir,S_IRWXU);
-    config=read_conf(); 
+    read_conf();
     window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
     sprintf(imagefile, "%s/pixmaps/cdw.png", CDWDIR);
     icon=gdk_pixbuf_new_from_file(imagefile, NULL);
@@ -1364,7 +1364,7 @@ int gtk_gui(int argc, char *argv[])
     toolbar=gtk_toolbar_new();
     gtk_box_pack_start(GTK_BOX(main_vbox), toolbar, FALSE, FALSE, 0);
     gtk_widget_show(toolbar);
-    
+
     add_toolbar_item(toolbar, _("CD label"), _("Display CD label editor window"), "cdlabel.png", 0, toolbar_images[1], toolbar_items[1], GTK_SIGNAL_FUNC(volume_id_gtk));
     add_toolbar_item(toolbar, _("Parameters"), _("Edit cdrecord parameters"), "parameters.png", 1, toolbar_images[2], toolbar_items[2], GTK_SIGNAL_FUNC(parameters_gtk));
     add_toolbar_item(toolbar, _("CD Size"), _("Select the size of disk"), "cdsize.png", 2, toolbar_images[3], toolbar_items[3], GTK_SIGNAL_FUNC(select_size_gtk));
@@ -1410,7 +1410,7 @@ int gtk_gui(int argc, char *argv[])
     gtk_signal_connect(GTK_OBJECT(button[7]), "clicked", GTK_SIGNAL_FUNC(blank_cdrw_gtk), NULL);
     gtk_signal_connect(GTK_OBJECT(button[8]), "clicked", GTK_SIGNAL_FUNC(options_gtk), NULL);
     /*********************/
-    
+
     gtk_signal_connect(GTK_OBJECT(button[9]), "clicked", GTK_SIGNAL_FUNC(QuitCdw), NULL);
     for (i=0; i<=9; i++) {
 	    gtk_box_pack_start(GTK_BOX(menu_box), button[i], FALSE, FALSE, 0);
@@ -1468,7 +1468,7 @@ int gtk_gui(int argc, char *argv[])
     gtk_widget_show(main_hbox);
     gtk_widget_show(main_vbox);
     gtk_widget_show(window1);
-    
+
     fill_info_gtk();
     select_window_gtk(TRUE);
     gdk_threads_enter();
