@@ -34,16 +34,21 @@ struct conf {
     char highq[2];
     char bitrate[4];
     int cdsize;
+    int user_cdsize;
     char cdbhost[255];
     char cdbuser[20];
     char sqlite_file[256];
     char bootimg[256];
 };
 
-struct conf read_conf(void);
-int inbox(WINDOW *input, char *init);
-void write_conf(struct conf config);
-void put_ckbox(WINDOW *win, int y, int x);
+
+int options_init(void);
+void options_clean(void);
+
+int read_conf(void);
+int write_conf(void);
+
 void options_window(void);
 
-#endif
+
+#endif /* __OPTIONS_H */
