@@ -33,6 +33,8 @@
 #include <time.h>
 #include <libintl.h>
 // #include <signal.h> // kill
+
+#include "cdw_widgets.h"
 #include "options.h"
 #include "gettext.h"
 #include "isosize.h"
@@ -90,14 +92,14 @@ char buf_err[BUFSIZE], buffer_err[BUFSIZE + 1];
 
 
 /*
- * print_stdout and print_stderr are two functions reading from 
+ * print_stdout and print_stderr are two functions reading from
  * stdout (stdout_pipe[0]) and stderr (stderr_pipe[0])
  * of other process - this process creates image, writes disc or sth else.
- * Purpose of this two functions is to intercept output of this process, extract 
- * useful information about state and progress (using regular expressions) and 
+ * Purpose of this two functions is to intercept output of this process, extract
+ * useful information about state and progress (using regular expressions) and
  * print this information in UI window. This interception is done by reading from
- * sockets that are connected to stdout and stderr of process. Creation of process 
- * and connection of sockets is done in run_command(). 
+ * sockets that are connected to stdout and stderr of process. Creation of process
+ * and connection of sockets is done in run_command().
  *
  */
 
@@ -112,14 +114,14 @@ void *print_stdout(void *dummy)
 	int data_processed;
 
 	// regular expressions setup code
-	
-	// Image writing...    
+
+	// Image writing...
 	regex = (regex_t *) calloc(1, sizeof(regex_t));
 	rv = regcomp(regex, "Track ([0-9]+): ([ ]*)([0-9]+) of ([ ]*)([0-9]+) MB written ([(])fifo([ ]*)([0-9]+)", REG_EXTENDED);
 	matches = (regmatch_t *) calloc(1, (regex->re_nsub + 1) * sizeof(regmatch_t));
 	if (rv) {
 		regerror(rv, NULL, buf, sizeof(buf));
-		fprintf(stderr, "ERROR regcomp: %s\n", buf);
+		fprintf(stderr, _("ERROR regcomp: %s\n"), buf);
 		exit(1);
 	}
 	// Direct writing...
@@ -128,7 +130,7 @@ void *print_stdout(void *dummy)
 	matches3 = (regmatch_t *) calloc(1, (regex3->re_nsub + 1) * sizeof(regmatch_t));
 	if (rv) {
 		regerror(rv, NULL, buf, sizeof(buf));
-		fprintf(stderr, "ERROR regcomp: %s\n", buf);
+		fprintf(stderr, _("ERROR regcomp: %s\n"), buf);
 		exit(1);
 	}
 	// Fixating...
@@ -137,7 +139,7 @@ void *print_stdout(void *dummy)
 	matches2 = (regmatch_t *) calloc(1, (regex2->re_nsub + 1) * sizeof(regmatch_t));
 	if (rv) {
 		regerror(rv, NULL, buf, sizeof(buf));
-		fprintf(stderr, "ERROR regcomp: %s\n", buf);
+		fprintf(stderr, _("ERROR regcomp: %s\n"), buf);
 		exit(1);
 	}
 	// Is erasable...
@@ -146,7 +148,7 @@ void *print_stdout(void *dummy)
 	matches4 = (regmatch_t *) calloc(1, (regex4->re_nsub + 1) * sizeof(regmatch_t));
 	if (rv) {
 		regerror(rv, NULL, buf, sizeof(buf));
-		fprintf(stderr, "ERROR regcomp: %s\n", buf);
+		fprintf(stderr, _("ERROR regcomp: %s\n"), buf);
 		exit(1);
 	}
 	// this media does not support blanking
@@ -155,10 +157,10 @@ void *print_stdout(void *dummy)
 	matches5 = (regmatch_t *) calloc(1, (regex5->re_nsub + 1) * sizeof(regmatch_t));
 	if (rv) {
 		regerror(rv, NULL, buf, sizeof(buf));
-		fprintf(stderr, "ERROR regcomp: %s\n", buf);
+		fprintf(stderr, _("ERROR regcomp: %s\n"), buf);
 		exit(1);
 	}
-	
+
 
 	// regular expressions prepared, let's get some data
 
@@ -172,7 +174,7 @@ void *print_stdout(void *dummy)
 			fprintf(logf, buffer);
 			fflush(logf);
 
-			// case 1: Image writing...    
+			// case 1: Image writing...
 			rv1 = regexec(regex, buffer, regex->re_nsub + 1, matches, 0);
 			if (rv1 == 0) {
 				// image writing
@@ -208,7 +210,7 @@ void *print_stdout(void *dummy)
 			}
 		} else if (data_processed == 0) { // EOF
 			break;
-		} 
+		}
 		pthread_mutex_unlock(&mutex);
 		if (data_processed == 0)
 			break;
@@ -248,7 +250,7 @@ void *print_stderr(void *dummy)
 	matches = (regmatch_t *) calloc(1, (regex->re_nsub + 1) * sizeof(regmatch_t));
 	if (rv) {
 		regerror(rv, NULL, buf_err, sizeof(buf_err));
-		fprintf(stderr, "ERROR regcomp: %s\n", buf_err);
+		fprintf(stderr, _("ERROR regcomp: %s\n"), buf_err);
 		exit(1);
 	}
 
@@ -258,7 +260,7 @@ void *print_stderr(void *dummy)
 	matches2 = (regmatch_t *) calloc(1, (regex2->re_nsub + 1) * sizeof(regmatch_t));
 	if (rv) {
 		regerror(rv, NULL, buf_err, sizeof(buf_err));
-		fprintf(stderr, "ERROR regcomp: %s\n", buf_err);
+		fprintf(stderr, _("ERROR regcomp: %s\n"), buf_err);
 		exit(1);
 	}
 	// cannot write medium - incompatible format
@@ -267,7 +269,7 @@ void *print_stderr(void *dummy)
 	matches3 = (regmatch_t *) calloc(1, (regex3->re_nsub + 1) * sizeof(regmatch_t));
 	if (rv) {
 		regerror(rv, NULL, buf, sizeof(buf));
-		fprintf(stderr, "ERROR regcomp: %s\n", buf);
+		fprintf(stderr, _("ERROR regcomp: %s\n"), buf);
 		exit(1);
 	}
 	// Cannot blank disk
@@ -276,7 +278,7 @@ void *print_stderr(void *dummy)
 	matches4 = (regmatch_t *) calloc(1, (regex4->re_nsub + 1) * sizeof(regmatch_t));
 	if (rv) {
 		regerror(rv, NULL, buf, sizeof(buf));
-		fprintf(stderr, "ERROR regcomp: %s\n", buf);
+		fprintf(stderr, _("ERROR regcomp: %s\n"), buf);
 		exit(1);
 	}
 
@@ -321,7 +323,7 @@ void *print_stderr(void *dummy)
 
 		} else if (data_processed_err == 0) { // EOF
 			break;
-		} 
+		}
 		pthread_mutex_unlock(&mutex);
 		if (data_processed_err == 0)
 			break;
@@ -368,7 +370,7 @@ void create_process_win(int is_process, char *cmd)
 	wprintw(processwin, " %s ", window);
 	waddch(processwin, ACS_LTEE);
 	*/
-	nice_box(processwin, window, "", 0);
+	nice_box(processwin, window, "");
 
 	if (is_process != 0)
 		box(derwin(processwin, 3, 22, 4, 4), 0, 0);
@@ -412,7 +414,7 @@ int copy_image(char *window_name)
 	if ((cpy_buf = (void *) malloc(IMAGE_BUF)) == NULL) {
 		return -1;
 	}
-	
+
 	if ((cdimage = open(config.cdrom, O_RDWR | O_NONBLOCK)) == -1) {
 		return -1;
 	}
@@ -431,7 +433,7 @@ int copy_image(char *window_name)
 		if (n == 0) {
 			break; /* EOF */
 		} else if (n == -1) {
-			dialogbox("Please check your cdrom settings and try to disable readahead.", "CDROM read error", 0);
+			dialogbox(_("CD drive read error"), _("Please check your cdrom settings and try to disable readahead."), 0);
 			/// wrefresh(derwin(mainwin,LINES-1,COLS-1,0,0));
 			/// select_window(FALSE);
 			// wrefresh(mainwin);
@@ -456,12 +458,12 @@ int copy_image(char *window_name)
 
 	// wrefresh(mainwin);
 	// wrefresh(processwin);
-	nice_box(processwin, window_name, "", 0);
+	nice_box(processwin, window_name, "");
 	mvwprintw(processwin, 9, 4, _("     PRESS any key     "));
 	wrefresh(processwin);
 	c = wgetch(processwin);
 
-	
+
 	destroy_process_win();
 
 	free(cpy_buf);
@@ -471,7 +473,7 @@ int copy_image(char *window_name)
 
 
 /*
- * Run command: create sockets to new process and 
+ * Run command: create sockets to new process and
  * launch given program as new process
  *
  * \param char commnad[] - program name + it's arguments
@@ -492,15 +494,15 @@ int run_command(char command[200], char *window_name, int dsize, int wait, int i
 	size = dsize / 1024 / 1024;
 	if ((logf = fopen(config.logfile, "w")) == NULL) {
 		endwin();
-		fprintf(stderr, _("Cannot create logfile..."));
+		fprintf(stderr, _("Cannot create logfile...\n"));
 		exit(-1);
 	}
 	lasttrack = 0;
 	//track=0;
 	time0 = time(NULL);
-	fprintf(logf, "Time: %d\n", (int)time0);
+	fprintf(logf, _("Time: %d\n"), (int)time0);
 	fprintf(logf, "%s\n", command);
-	if ((socketpair(AF_UNIX, SOCK_STREAM, 0, stdin_pipe) == 0) 
+	if ((socketpair(AF_UNIX, SOCK_STREAM, 0, stdin_pipe) == 0)
 	    && (socketpair(AF_UNIX, SOCK_STREAM, 0, stdout_pipe) == 0)
 	    && (socketpair(AF_UNIX, SOCK_STREAM, 0, stderr_pipe) == 0)) {
 
@@ -513,7 +515,7 @@ int run_command(char command[200], char *window_name, int dsize, int wait, int i
 		fork_result = fork();
 
 		if (fork_result == -1) {
-			fprintf(stderr, _("Fork Failure\n"));
+			fprintf(stderr, _("Fork failure\n"));
 			exit(-1);
 		} else if (fork_result == 0) { // we are child process
 			char *argv[4];
@@ -523,14 +525,14 @@ int run_command(char command[200], char *window_name, int dsize, int wait, int i
 			 * instead we should write to socked inherited from parent process,
 			 * so parent process can know what we are doing and what's going on
 			 *
-			 * dup() will copy it's argument descriptors to lowest available 
-			 * descriptors; let's make stdin, stdout and stderr 
+			 * dup() will copy it's argument descriptors to lowest available
+			 * descriptors; let's make stdin, stdout and stderr
 			 * 'lowest avaliable' by closing them before calling dup();
 			 *
 			 * let's close original descriptor after copying it:
 			 * we have copy, original is no longer needed; we don't need
 			 * the other end of pipe here either (that is why we close both
-			 * *_pipe[0] and *_pipe[1]), but parent will keep the other end 
+			 * *_pipe[0] and *_pipe[1]), but parent will keep the other end
 			 * open to read from it as we write to our new stdout and stderr
 			 */
 			close(0);
@@ -555,10 +557,10 @@ int run_command(char command[200], char *window_name, int dsize, int wait, int i
 			argv[2] = cmd;
 			argv[3] = NULL;
 			execvp(argv[0], argv);
-			
+
 			/* exec*() functions don't return */
 
-			fprintf(stderr, "exec() returns\n");
+			fprintf(stderr, _("Error: return of exec() function\n"));
 
 			exit(0);
 		} else { // we are still in parent process
@@ -566,7 +568,7 @@ int run_command(char command[200], char *window_name, int dsize, int wait, int i
 			pthread_t pout, perr;
 
 			/* it is the parent process that intercepts output messages from
-			 * mkisofs or cdrecord, so parent process must aso create process 
+			 * mkisofs or cdrecord, so parent process must aso create process
 			 * info window, so it can write to it */
 			create_process_win(is_process, msg);
 
@@ -577,19 +579,19 @@ int run_command(char command[200], char *window_name, int dsize, int wait, int i
 
 			rv = pthread_create(&pout, NULL, &print_stdout, NULL);
 			if (rv != 0) {
-				fprintf(stderr, "thread stdout creation error");
+				fprintf(stderr, _("Thread stdout creation error"));
 			}
 			rv = pthread_create(&perr, NULL, &print_stderr, NULL);
 			if (rv != 0) {
-				fprintf(stderr, "thread stderr creation error");
+				fprintf(stderr, _("Thread stderr creation error"));
 			}
 
-			/* threads are created; now we must wait for them to complete 
+			/* threads are created; now we must wait for them to complete
 			 * their job and return (both of them);
 			 * when thead functions end we can execute pthread_join()s */
 			pthread_join(perr, NULL);
 			pthread_join(pout, NULL);
-			
+
 			/* nothing more to read from these two */
 			close(stderr_pipe[0]);
 			close(stdout_pipe[0]);
@@ -601,8 +603,8 @@ int run_command(char command[200], char *window_name, int dsize, int wait, int i
 			mvwprintw(processwin, 3, 15 - (strlen(_("Done")) / 2), _("Done"));
 			wrefresh(processwin);
 			mvwprintw(processwin, 5, 5, "");
-			
-			/* do we need to erase or change progress bar? 
+
+			/* do we need to erase or change progress bar?
 			draw_progress_bar(5, 5, 2, ACS_BLOCK); */
 
 			mvwprintw(processwin, 9, 29, "");
@@ -613,7 +615,7 @@ int run_command(char command[200], char *window_name, int dsize, int wait, int i
 			}
 
 			destroy_process_win();
-			/* erase remainings of process window before 
+			/* erase remainings of process window before
 			 * cd tray will open after writing */
 			wrefresh(derwin(mainwin, LINES - 1, COLS - 1, 0, 0));
 			select_window(FALSE);
@@ -621,7 +623,7 @@ int run_command(char command[200], char *window_name, int dsize, int wait, int i
 	} else {
 		exit(-1);
 	}
-	
+
 	return 1;
 }
 
@@ -672,7 +674,7 @@ void eta_calculations(int eta, char *seta_hour, char *seta_min, char *seta_sec)
 /**
  * Update ETA information in process progress information window
  *
- * \param WINDOW *processwin 
+ * \param WINDOW *processwin
  * \param int eta
  *
  * FIXME - processwin is global variable
@@ -687,7 +689,7 @@ void update_processwin_eta(WINDOW *processwin, int eta)
 	eta_calculations(eta, seta_hour, seta_min, seta_sec);
 
 	mvwprintw(processwin, 9, 1, "                            ");
-	sprintf(etime, "ETA: %s:%s.%s", seta_hour, seta_min, seta_sec);
+	sprintf(etime, _("ETA: %s:%s.%s"), seta_hour, seta_min, seta_sec);
 	mvwprintw(processwin, 9, 15 - (strlen(etime) / 2), "%s", etime);
 
 	return;
@@ -877,7 +879,7 @@ void handle_audio_grab(char *c5)
 			wattrset(processwin, COLOR_PAIR(2));
 		}
 		*/
-		sprintf(percent, "  %d%% %s  ", perc, _("done"));
+		sprintf(percent, _("  %d%% done  "), perc);
 		mvwprintw(processwin, 3, 15 - (strlen(percent) / 2), "%s", percent);
 		//mvwprintw(processwin, 5, 5, "");
 		//mvwprintw(processwin, 9, 29, "");
@@ -897,17 +899,16 @@ void handle_audio_grab(char *c5)
 
 
 
-/*
+/**
  * Handle normal mkisofs output during image creation
  *
  * Normal mkisofs output durnig image creation is follownig:
  * '58.65% done, estimate finish Sat Mar  3 21:20:06 2007'.
- * mkisofs doesn't write 100% value therefore handle_image_creation_100percent
+ * mkisofs doesn't write 100% value therefore handle_image_creation_100percent()
  * is needed.
  */
 void handle_image_creation(regex_t *regex, regmatch_t *matches)
 {
-	// write direct 1
 	int i;
 	char percent[30];
 	for (i = 0; i < (regex->re_nsub + 1); ++i) {
@@ -956,7 +957,7 @@ void handle_image_creation(regex_t *regex, regmatch_t *matches)
  * 127880 extents written (249 MB)
  * '
  *
- * This function is called after capturing 
+ * This function is called after capturing
  * 'Total translation table size: 0'
  */
 void handle_image_creation_100percent(regex_t *regex, regmatch_t *matches)
@@ -1025,12 +1026,12 @@ void handle_is_erasable(regex_t *regex, regmatch_t *matches)
 	strncpy(buf, (char *) &buffer[matches[0].rm_so], len);
 	buf[len] = '\0';
 
-	dialogbox(buf, "ATIP message", 0);
+	dialogbox("ATIP message", buf, 0);
 	wrefresh(derwin(mainwin,LINES-1,COLS-1,0,0));
 	select_window(FALSE);
 	*/
 	media_erasable = MEDIA_ERASABLE_YES;
-	
+
 	return;
 }
 
@@ -1045,3 +1046,5 @@ void handle_blanking_not_supported(regex_t *regex, regmatch_t *matches)
 
 	return;
 }
+
+
